@@ -1,6 +1,6 @@
 #!/bin/sh
 # bootstrap.sh -- shell script to build the m17n library from CVS.
-# Copyright (C) 2003, 2004, 2005, 2006, 2009
+# Copyright (C) 2003, 2004, 2005, 2006, 2009, 2010, 2011, 2012
 #   National Institute of Advanced Industrial Science and Technology (AIST)
 #   Registration Number H15PRO112
 
@@ -21,8 +21,15 @@
 # Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
+echo "Cleaning up old files..."
+rm -rf INSTALL aclocal.m4 autom4te.cache config.guess config.rpath config.sub install-sh libtool ltmain.sh missing mkinstalldirs intl/[D-Za-z]* m4/[a-z]*
+
 echo "Running autoreconf -v -f -i"
 autoreconf -v -f -i
+if [ ! -f po/Makevars ] ; then
+    echo "Copying po/Makevars.template to po/Makevars"
+    cp po/Makevars.template po/Makevars
+fi
 echo "The remaining steps to install this library are:"
 echo "  % ./configure"
 echo "  % make"
