@@ -1,5 +1,5 @@
 /* character.c -- character module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nCharacter
@@ -42,21 +42,21 @@
 
 /***ja
     @addtogroup m17nCharacter
-    @brief ʸ֥ȤȤ˴ؤ API.
+    @brief 文字オブジェクトとそれに関する API.
 
-    m17n 饤֥ @e ʸ ʸɡˤɽ롣
-    Ǿʸɤ @c 0 Ǥꡢʸɤϥޥ #MCHAR_MAX 
-    ˤäƤ롣#MCHAR_MAX  @c 0x3FFFFF22ӥåȡ
-    ʾǤ뤳ȤݾڤƤ롣
+    m17n ライブラリは @e 文字 を文字コード（整数）で表現する。
+    最小の文字コードは @c 0 であり、最大の文字コードはマクロ #MCHAR_MAX 
+    によって定義されている。#MCHAR_MAX は @c 0x3FFFFF（22ビット）
+    以上であることが保証されている。
 
-    @c 0  @c 0x10FFFF ޤǤʸϡƱͤ Unicode 
-    ʸ˳ƤƤ롣
+    @c 0 から @c 0x10FFFF までの文字は、それと同じ値を持つ Unicode 
+    の文字に割り当てられている。
 
-    ʸ @e ʸץѥƥ ȸƤ֥ץѥƥ 0 İʾĤȤǤ롣
-    ʸץѥƥ @e   @e  ʤ롣
-    ϥܥǤꡢͤ <tt>(void *)</tt> ˥㥹ȤǤΤʤ鲿Ǥ褤 
-    ʸ C ʸץѥƥΤ K ǤΡפñˡʸ C 
-     K ץѥƥפȸƤ֤Ȥ롣  */
+    各文字は @e 文字プロパティ と呼ぶプロパティを 0 個以上持つことができる。
+    文字プロパティは @e キー と @e 値 からなる。
+    キーはシンボルであり、値は <tt>(void *)</tt> 型にキャストできるものなら何でもよい。 
+    「文字 C の文字プロパティのうちキーが K であるもの」を簡単に「文字 C 
+    の K プロパティ」と呼ぶことがある。  */
 /*=*/
 
 #if !defined (FOR_DOXYGEN) || defined (DOXYGEN_INTERNAL_MODULE)
@@ -186,9 +186,9 @@ mchar__define_prop (MSymbol key, MSymbol type, void *mdb)
     The macro #MCHAR_MAX gives the maximum character code.  */
 
 /***ja
-    @brief ʸɤκ.
+    @brief 文字コードの最大値.
 
-    ޥ #MCHAR_MAX ʸɤκͤɽ  */
+    マクロ #MCHAR_MAX は文字コードの最大値を表す。  */
 
 #define MCHAR_MAX
 /*=*/
@@ -201,9 +201,9 @@ mchar__define_prop (MSymbol key, MSymbol type, void *mdb)
 
 /***ja
     @ingroup m17nCharacter
-    @name ѿ: ʸץѥƥΥ
+    @name 変数: 文字プロパティのキー
 
-    ΥܥʸץѥƥΥȤƻȤ롣*/
+    これらのシンボルは文字プロパティのキーとして使われる。*/
 
 /*=*/
 /*** @{ */
@@ -219,14 +219,14 @@ mchar__define_prop (MSymbol key, MSymbol type, void *mdb)
     the <em>Unicode Technical Report #24</em>.  */
 
 /***ja
-    @brief ץȤɽ魯.
+    @brief スクリプトを表わすキー.
 
-    ܥ #Mscript  <tt>"script"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡʸ°륹ץȤɽ魯ܥǤ롣
+    シンボル #Mscript は <tt>"script"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、この文字の属するスクリプトを表わすシンボルである。
 
-    ץȤɽ魯ܥ̾ϡ<em>Unicode Technical Report
-    #24</em> ˥ꥹȤƤΤΤ줫Ǥ롣  */
+    スクリプトを表わすシンボルの名前は、<em>Unicode Technical Report
+    #24</em> にリストされているもののいずれかである。  */
 
 MSymbol Mscript;
 
@@ -240,11 +240,11 @@ MSymbol Mscript;
     C-string representing the name of the character.  */
 
 /***ja
-    @brief ̾ɽ魯.
+    @brief 名前を表わすキー.
 
-    ܥ #Mname  <tt>"name"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    ΥץѥƥͤϤʸ̾ɽ魯 C ʸǤ롣  */
+    シンボル #Mname は <tt>"name"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値はその文字の名前を表わす C の文字列である。  */
 
 MSymbol Mname;
 
@@ -263,14 +263,14 @@ MSymbol Mname;
     Unicode.  */
 
 /***ja
-    @brief ̥ƥɽ魯.
+    @brief 一般カテゴリを表わすキー.
 
-    ܥ #Mcategory  <tt>"category"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡб <em>̥ƥ</em> ɽ魯ܥǤ롣
+    シンボル #Mcategory は <tt>"category"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、対応する <em>一般カテゴリ</em> を表わすシンボルである。
 
-    ̥ƥɽ魯ܥ̾ϡ<em>General Category</em> 
-    ξάȤ Unicode ƤΤǤ롣  */
+    一般カテゴリを表わすシンボルの名前は、<em>General Category</em> 
+    の省略形として Unicode に定義されているものである。  */
 
 MSymbol Mcategory;
 
@@ -288,14 +288,14 @@ MSymbol Mcategory;
     class is identical to the one defined in Unicode.  */
 
 /***ja
-    @brief ɸ祯饹ɽ魯.
+    @brief 標準結合クラスを表わすキー.
 
-    ܥ #Mcombining_class  <tt>"combining-class"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡб @e ɸ祯饹 ɽ魯Ǥ롣
+    シンボル #Mcombining_class は <tt>"combining-class"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、対応する @e 標準結合クラス を表わす整数である。
 
-    ɸ祯饹ɽ魯ΰ̣ϡUnicode 
-    ƤΤƱǤ롣  */
+    標準結合クラスを表わす整数の意味は、Unicode 
+    に定義されているものと同じである。  */
 
 MSymbol Mcombining_class;
 /*=*/
@@ -313,14 +313,14 @@ MSymbol Mcombining_class;
     Unicode.  */
 
 /***ja
-    @brief ƥɽ魯.
+    @brief 双方向カテゴリを表わすキー.
 
-    ܥ #Mbidi_category  <tt>"bidi-category"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡб @e ƥ ɽ魯ܥǤ롣
+    シンボル #Mbidi_category は <tt>"bidi-category"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、対応する @e 双方向カテゴリ を表わすシンボルである。
 
-    ƥɽ魯ܥ̾ϡ<em>Bidirectional
-    Category</em> ηȤ Unicode ƤΤǤ롣  */
+    双方向カテゴリを表わすシンボルの名前は、<em>Bidirectional
+    Category</em> の型として Unicode に定義されているものである。  */
 
 MSymbol Mbidi_category;
 /*=*/
@@ -340,16 +340,16 @@ MSymbol Mbidi_category;
     another property whose key is #Mcomplicated_case_folding.  */
 
 /***ja
-    @brief б뾮ʸʸɽ魯.
+    @brief 対応する小文字一文字を表わすキー.
 
-    ܥ #Msimple_case_folding  <tt>"simple-case-folding"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡб뾮ʸʸǤꡢʸʸζ̵̤뤷ʸӤκݤ˻Ȥ롣
+    シンボル #Msimple_case_folding は <tt>"simple-case-folding"</tt> 
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、対応する小文字一文字であり、大文字／小文字の区別を無視した文字列比較の際に使われる。
 
-    ʣˡɬפȤʸǤä
-    ̤ΰʸбդ뤳ȤˤäӤǤʤˡΥץѥƥͤ 
-    @c 0xFFFF ˤʤ롣ξ礽ʸϡ#Mcomplicated_case_folding
-    Ȥʸץѥƥġ  */
+    複雑な比較方法を必要とする文字であった場合
+    （別の一文字と対応付けることによって比較できない場合）、このプロパティの値は 
+    @c 0xFFFF になる。この場合その文字は、#Mcomplicated_case_folding
+    というキーの文字プロパティを持つ。  */
 
 MSymbol Msimple_case_folding;
 /*=*/
@@ -364,13 +364,13 @@ MSymbol Msimple_case_folding;
     characters to be used for comparing M-texts ignoring case.  */
 
 /***ja
-    @brief б뾮ʸɽ魯.
+    @brief 対応する小文字の列を表わすキー.
 
-    ܥ #Mcomplicated_case_folding  
+    シンボル #Mcomplicated_case_folding は 
     <tt>"complicated-case-folding"</tt> 
-    Ȥ̾ʸץѥƥΥȤƻȤ롣
-    Υץѥƥͤϡб뾮ʸ󤫤ʤ M-text Ǥꡢʸʸζ̵̤뤷ʸӤκݤ˻
-    롣
+    という名前を持ち、文字プロパティのキーとして使われる。
+    このプロパティの値は、対応する小文字列からなる M-text であり、大文字／小文字の区別を無視した文字列比較の際に使
+    われる。
       */
 
 MSymbol Mcomplicated_case_folding;
@@ -387,13 +387,13 @@ MSymbol Mcomplicated_case_folding;
  */
 
 /***ja
-    @brief Case ѤͤΥ.
+    @brief Case 処理に用いられる値のキー.
 
-    ܥ #Mcased ϡ<tt>"cased"</tt> Ȥ̾ʸץ
-    ƥΥȤƻȤ롣Υץѥƥͤ 1, 2, 3 Τ
-    줫Ǥꡢ줾 "cased", "case-ignorable", ξ̣롣
-    ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13 Default
-    Case Algorithm) ȡ
+    シンボル #Mcased は、<tt>"cased"</tt> という名前を持ち、文字プロパ
+    ティのキーとして使われる。このプロパティの値は整数値 1, 2, 3 のいず
+    れかであり、それぞれ "cased", "case-ignorable", その両方を意味する。
+    詳細については、the Unicode Standard 5.0 (Section 3.13 Default
+    Case Algorithm) 参照。
  */
 MSymbol Mcased;
 
@@ -408,13 +408,13 @@ MSymbol Mcased;
     Default Case Algorithm) for the detail.  */
 
 /***ja
-    @brief Case ѤͤΥ.
+    @brief Case 処理に用いられる値のキー.
 
-    ܥ #Msoft_dotted ϡ<tt>"soft-dotted"</tt> Ȥ̾
-    ʸץѥƥΥȤƻȤ롣Υץѥƥͤϡʸ
-    "Soft_Dotted"ץѥƥľˤ #Mt, Ǥʤ #Mnil 
-    롣 ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13
-    Default Case Algorithm) ȡ
+    シンボル #Msoft_dotted は、<tt>"soft-dotted"</tt> という名前を持ち、
+    文字プロパティのキーとして使われる。このプロパティの値は、文字が
+    "Soft_Dotted"プロパティを持つ場合には #Mt, そうでなければ #Mnil で
+    ある。 詳細については、the Unicode Standard 5.0 (Section 3.13
+    Default Case Algorithm) 参照。
  */
 MSymbol Msoft_dotted;
 
@@ -429,13 +429,13 @@ MSymbol Msoft_dotted;
     (Section 5.18 Case Mappings) for the detail.  */
 
 /***ja
-    @brief Case ѤͤΥ.
+    @brief Case 処理に用いられる値のキー.
 
-    ܥ #Mcase_mapping ϡ<tt>"case-mapping"</tt> Ȥ̾
-    ʸץѥƥΥȤƻȤ롣Υץѥƥͤϡ
-     M-textʤʸ lower, title,  upperʤ plist
-    Ǥ롣 ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13
-    Default Case Algorithm) ȡ
+    シンボル #Mcase_mapping は、<tt>"case-mapping"</tt> という名前をも
+    ち、文字プロパティのキーとして使われる。このプロパティの値は、３つ
+    の M-text、すなわちその文字の lower, title, と upperからなる plist
+    である。 詳細については、the Unicode Standard 5.0 (Section 3.13
+    Default Case Algorithm) 参照。
 */
 MSymbol Mcase_mapping;
 
@@ -448,11 +448,11 @@ MSymbol Mcase_mapping;
     symbol representing a script block of the corresponding
     character.  */
 /***ja
-    @brief ץȥ֥å̾ɽ.
+    @brief スクリプトブロック名を表すキー.
 
-    ܥ #Mblock ϡ<tt>"block"</tt> Ȥ̾ʸץ
-    ƥΥȤƻȤ롣ΥץѥƥͤϡʸΥ
-    ȥ֥å̾ɽܥǤ롣*/
+    シンボル #Mblock は、<tt>"block"</tt> という名前をもち、文字プロパ
+    ティのキーとして使われる。このプロパティの値は、その文字のスクリプ
+    トブロック名を表すシンボルである。*/
 MSymbol Mblock;
 
 /*** @} */
@@ -471,16 +471,16 @@ MSymbol Mblock;
     $SYM.  Otherwise it returns #Mnil.  */
 
 /***ja
-    @brief ʸץѥƥ.
+    @brief 文字プロパティを定義する.
 
-    ؿ mchar_define_property () ϡ \<#Mchar_table, $TYPE, $SYM \>
-    Ȥäǡ١ m17n ١õ  
-     $SYM  $NAME Ȥ̾ΥܥǤ롣$TYPE #Mstring,
-    #Mtext, #Msymbol, #Minteger, #Mplist Τ줫ǤʤФʤʤ
+    関数 mchar_define_property () は、 \<#Mchar_table, $TYPE, $SYM \>
+    というタグを持ったデータベースを m17n 言語情報ベースから探す。  
+    ここで $SYM は $NAME という名前のシンボルである。$TYPE は#Mstring,
+    #Mtext, #Msymbol, #Minteger, #Mplist のいずれかでなければならない。
 
     @return
-     mchar_define_property () $SYM ֤
-    Ԥ #Mnil ֤  */
+    処理に成功すれば mchar_define_property () は$SYM を返す。
+    失敗した場合は #Mnil を返す。  */
 
 /***
     @errors
@@ -516,14 +516,14 @@ mchar_define_property (const char *name, MSymbol type)
     NULL.  */
 
 /***ja
-    @brief ʸץѥƥͤ.
+    @brief 文字プロパティの値を得る.
 
-    ؿ mchar_get_prop () ϡʸ $C ʸץѥƥΤ 
-    $KEY ǤΤõ
+    関数 mchar_get_prop () は、文字 $C の文字プロパティのうちキーが 
+    $KEY であるものを探す。
 
     @return
-     mchar_get_prop () ϸĤäץѥƥ֤ͤ
-    Ԥ @c NULL ֤
+    処理が成功すれば mchar_get_prop () は見つかったプロパティの値を返す。
+    失敗した場合は @c NULL を返す。
 
     @latexonly \IPAlabel{mchar_get_prop} @endlatexonly
 */
@@ -567,13 +567,13 @@ mchar_get_prop (int c, MSymbol key)
     If the operation was successful, mchar_put_prop () returns 0.
     Otherwise, it returns -1.  */
 /***ja
-    @brief ʸץѥƥͤꤹ.
+    @brief 文字プロパティの値を設定する.
 
-    ؿ mchar_put_prop () ϡʸ $C ʸץѥƥΤ $KEY 
-    ǤΤõͤȤ $VAL ꤹ롣
+    関数 mchar_put_prop () は、文字 $C の文字プロパティのうちキーが $KEY 
+    であるものを探し、その値として $VAL を設定する。
 
     @return
-     mchar_put_prop () 0֤Ԥ-1֤  */
+    処理が成功すれば mchar_put_prop () は0を返す。失敗した場合は-1を返す。  */
 /***
     @errors
     @c MERROR_SYMBOL, @c MERROR_DB
@@ -617,16 +617,16 @@ mchar_put_prop (int c, MSymbol key, void *val)
     char-table.  Otherwise NULL is retuned.  */
 
 /***ja
-    @brief ʸץѥƥʸơ֥.
+    @brief 文字プロパティの文字テーブルを得る.
 
-    ؿ mchar_get_prop_table () ϡ $KEY Ǥʸץѥƥ
-    ޤʸơ֥֤⤷ $TYPE  NULL ǤʤС $TYPE 
-    ؤˤʸΥץѥƥǼ롣ʸץѥƥμ
-    ˴ؤƤ mchar_define_property () 򸫤衣
+    関数 mchar_get_prop_table () は、キーが $KEY である文字プロパティ
+    を含む文字テーブルを返す。もし $TYPE が NULL でなければ、 $TYPE で
+    指される場所にその文字のプロパティを格納する。文字プロパティの種類
+    に関しては mchar_define_property () を見よ。
 
     @return
-    ⤷ $KEY ʸץѥƥΥǤСʸơ֥뤬֤
-    롣Ǥʤ NULL ֤롣  */
+    もし $KEY が正当な文字プロパティのキーであれば、文字テーブルが返さ
+    れる。そうでない場合は NULL が返される。  */
 
 MCharTable *
 mchar_get_prop_table (MSymbol key, MSymbol *type)
@@ -654,6 +654,6 @@ mchar_get_prop_table (MSymbol key, MSymbol *type)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
