@@ -1,5 +1,5 @@
 /* charset.c -- charset module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 /***en
     @addtogroup m17nCharset
     @brief Charset objects and API for them.
@@ -52,29 +52,29 @@
 
 /***ja
     @addtogroup m17nCharset
-    @brief ʸåȥ֥ȤȤ˴ؤ API.
+    @brief 文字セットオブジェクトとそれに関する API.
 
-    m17n 饤֥ϡ沽ʸ (CCS)  @e ʸå 
-    ȸƤ֥֥Ȥɽ롣
-    m17n 饤֥¿沽ʸ򤢤餫᥵ݡȤƤ뤷ץꥱץबȼʸåȤɲä뤳ȤǽǤ롣
-    ĤʸʣʸåȤ°Ƥ褤
+    m17n ライブラリは、符号化文字集合 (CCS) を @e 文字セット 
+    と呼ぶオブジェクトで表現する。
+    m17n ライブラリは多くの符号化文字集合をあらかじめサポートしているし、アプリケーションプログラムが独自に文字セットを追加することも可能である。
+    一つの文字は複数の文字セットに属してもよい。
 
-    m17n 饤֥ϡʲγǰ̤Ƥ:
+    m17n ライブラリは、以下の概念を区別している:
 
-    @li @e ɥݥ ȤϡCCS θġʸФͤǤ롣
-    ɥݥȤϢ³ƤȤϸ¤ʤɥݥȤ
-    @c unsigned ˤäɽ롣̵ʥɥݥȤϥޥ
-    @c MCHAR_INVALID_CODE ɽ롣
+    @li @e コードポイント とは、CCS がその中の個々の文字に対して定義する数値である。
+    コードポイントは連続しているとは限らない。コードポイントは
+    @c unsigned 型によって表される。無効なコードポイントはマクロ
+    @c MCHAR_INVALID_CODE で表される。
 
-    @li @e ʸǥå ȤϡCCS ǳʸ˳Ƥ줿ǥåǤ롣
-    ʸǥå N ʸϡCCS ʸ򥳡ɥݥȽ¤٤Ȥ N ܤ˸롣
-    CCS ʸǥåϢ³Ƥꡢ0 Ϥޤ롣
+    @li @e 文字インデックス とは、CCS 内で各文字に割り当てられる正規化されたインデックスである。
+    文字インデックスが N の文字は、CCS 中の全文字をコードポイント順に並べたときに N 番目に現われる。
+    CCS 中の文字インデックスは連続しており、0 から始まる。
 
-    @li @e ʸ Ȥϡm17n 饤֥ˤʸɽǤꡢ21 ӥåȰʾĹդǤ롣
+    @li @e 文字コード とは、m17n ライブラリ内における文字の内部表現であり、21 ビット以上の長さを持つ符合付き整数である。
 
-    ʸåȥ֥ȤϡʸåȤ°ʸΥɥݥȤʸɤȤδ֤Ѵꤹ롣
-    ɥݥȤʸɤؤѴ @e ǥ
-    ȸƤӡʸɤ饳ɥݥȤؤѴ @e 󥳡 ȸƤ֡  */
+    各文字セットオブジェクトは、その文字セットに属する文字のコードポイントと文字コードとの間の変換を規定する。
+    コードポイントから文字コードへの変換を @e デコード
+    と呼び、文字コードからコードポイントへの変換を @e エンコード と呼ぶ。  */
 
 
 /*=*/
@@ -673,7 +673,7 @@ mcharset__load_from_database ()
     return 0;
   MDEBUG_PUSH_TIME ();
   def_list = (MPlist *) mdatabase_load (mdb);
-  MDEBUG_PRINT_TIME ("CHARSET", (stderr, " to load data."));
+  MDEBUG_PRINT_TIME ("CHARSET", (mdebug__output, " to load data."));
   MDEBUG_POP_TIME ();
   if (! def_list)
     return -1;
@@ -699,7 +699,7 @@ mcharset__load_from_database ()
     }
 
   M17N_OBJECT_UNREF (def_list);
-  MDEBUG_PRINT_TIME ("CHARSET", (stderr, " to parse the loaded data."));
+  MDEBUG_PRINT_TIME ("CHARSET", (mdebug__output, " to parse the loaded data."));
   MDEBUG_POP_TIME ();
   return 0;
 }
@@ -710,8 +710,8 @@ mcharset__load_from_database ()
 
 /* External API */
 
-/*** @addtogroup m17nCharset */
-/*** @{ */
+/*** @addtogroup m17nCharset
+     @{ */
 /*=*/
 
 #ifdef FOR_DOXYGEN
@@ -721,9 +721,9 @@ mcharset__load_from_database ()
     The macro #MCHAR_INVALID_CODE gives the invalid code-point.  */
 
 /***ja
-    @brief ̵ʥɥݥ.
+    @brief 無効なコードポイント.
 
-    ޥ #MCHAR_INVALID_CODE ̵ʥɥݥȤ򼨤  */
+    マクロ #MCHAR_INVALID_CODE は無効なコードポイントを示す。  */
 
 #define MCHAR_INVALID_CODE
 #endif
@@ -736,9 +736,9 @@ mcharset__load_from_database ()
     Each of the following symbols represents a predefined charset.  */
 
 /***ja
-    @name ѿ: ʸåȤɽѤߥܥ.
+    @name 変数: 文字セットを表現する定義済みシンボル.
 
-    ʲγƥܥϡѤʸåȤɽ롣  */
+    以下の各シンボルは、定義済み文字セットを表現する。  */
 /*=*/
 /*** @{ */
 /*=*/
@@ -748,10 +748,10 @@ mcharset__load_from_database ()
     The symbol #Mcharset_ascii has name <tt>"ascii"</tt> and represents
     the charset ISO 646, USA Version X3.4-1968 (ISO-IR-6).  */
 /***ja
-    @brief ASCII ʸåȤɽ륷ܥ.
+    @brief ASCII 文字セットを表現するシンボル.
 
-    ܥ #Mcharset_ascii  <tt>"ascii"</tt> Ȥ̾ 
-    ISO 646, USA Version X3.4-1968 (ISO-IR-6) ʸåȤɽ롣
+    シンボル #Mcharset_ascii は <tt>"ascii"</tt> という名前を持ち、 
+    ISO 646, USA Version X3.4-1968 (ISO-IR-6) 文字セットを表現する。
      */
 
 MSymbol Mcharset_ascii;
@@ -763,10 +763,10 @@ MSymbol Mcharset_ascii;
     The symbol #Mcharset_iso_8859_1 has name <tt>"iso-8859-1"</tt>
     and represents the charset ISO/IEC 8859-1:1998.  */
 /***ja
-    @brief ISO/IEC 8859-1:1998 ʸåȤɽ륷ܥ.
+    @brief ISO/IEC 8859-1:1998 文字セットを表現するシンボル.
 
-    ܥ #Mcharset_iso_8859_1  <tt>"iso-8859-1"</tt> 
-    Ȥ̾ISO/IEC 8859-1:1998 ʸåȤɽ롣
+    シンボル #Mcharset_iso_8859_1 は <tt>"iso-8859-1"</tt> 
+    という名前を持ち、ISO/IEC 8859-1:1998 文字セットを表現する。
     */
 
 MSymbol Mcharset_iso_8859_1;
@@ -777,10 +777,10 @@ MSymbol Mcharset_iso_8859_1;
     The symbol #Mcharset_unicode has name <tt>"unicode"</tt> and
     represents the charset Unicode.  */
 /***ja
-    @brief Unicode ʸåȤɽ륷ܥ.
+    @brief Unicode 文字セットを表現するシンボル.
 
-    ܥ #Mcharset_unicode  <tt>"unicode"</tt> 
-    Ȥ̾Unicode ʸåȤɽ롣 */
+    シンボル #Mcharset_unicode は <tt>"unicode"</tt> 
+    という名前を持ち、Unicode 文字セットを表現する。 */
 
 MSymbol Mcharset_unicode;
 
@@ -792,10 +792,10 @@ MSymbol Mcharset_unicode;
     represents the charset that contains all characters supported by
     the m17n library.  */ 
 /***ja
-    @brief ʸޤʸåȤɽ륷ܥ.
+    @brief 全文字を含む文字セットを表現するシンボル.
 
-    ܥ #Mcharset_m17n  <tt>"m17n"</tt> Ȥ̾
-    m17n 饤֥꤬ƤʸޤʸåȤɽ롣 */
+    シンボル #Mcharset_m17n は <tt>"m17n"</tt> という名前を持ち、
+    m17n ライブラリが扱う全ての文字を含む文字セットを表現する。 */
 
 MSymbol Mcharset_m17n;
 
@@ -811,13 +811,13 @@ MSymbol Mcharset_m17n;
     See @ref m17nConv for more details.  */
 
 /***ja
-    @brief ǥɤǤʤʸʸåȤɽ륷ܥ.
+    @brief 正しくデコードできない文字の文字セットを表現するシンボル.
 
-    ܥ #Mcharset_binary  <tt>"binary"</tt> 
-    Ȥ̾ (fake) ʸåȤɽ롣
-    ǥɴؿϡM-text ΥƥȥץѥƥȤơ̵ʥХȡʥ󥹡ˤ֤ղä롣
+    シンボル #Mcharset_binary は <tt>"binary"</tt> 
+    という名前を持ち、偽の (fake) 文字セットを表現する。
+    デコード関数は、M-text のテキストプロパティとして、無効なバイト（シークエンス）に遭遇した位置を付加する。
 
-     ܺ٤ @ref m17nConv ȤΤȡ */
+     詳細は @ref m17nConv 参照のこと。 */
 
 MSymbol Mcharset_binary;
 
@@ -832,10 +832,10 @@ MSymbol Mcharset_binary;
     function mchar_define_charset () (which see).  */
 
 /***ja
-    @name ѿ: mchar_define_charset ѤΥѥ᡼
+    @name 変数: mchar_define_charset 用のパラメータ・キー
 
-    ϡؿ mchar_define_charset () ѤΥѥ᡼ȤƻȤ륷ܥǤ롣 
-    ܤϤδؿβ򻲾ȤΤȡ*/
+    これらは、関数 mchar_define_charset () 用のパラメータ・キーとして使われるシンボルである。 
+    詳しくはこの関数の解説を参照のこと。*/
 /*** @{ */
 /*=*/
 
@@ -870,14 +870,14 @@ MSymbol Maliases;
     function for the details.  */
 
 /***ja
-    @name ѿ: ʸåȤΥ᥽åɻ˻Ȥ륷ܥ
+    @name 変数: 文字セットのメソッド指定に使われるシンボル
 
-    ϡʸåȤ @e ᥽å ꤹ뤿ѤߥܥǤꡢʸåȤ
-    @b Mmethod ѥ᡼ͤȤʤ뤳ȤǤ롣
-    ͤϴؿ mchar_define_charset () ΰȤƻȤ롣
+    これらは、文字セットの @e メソッド を指定するための定義済みシンボルであり、文字セットの
+    @b Mmethod パラメータの値となることができる。
+    この値は関数 mchar_define_charset () の引数として使われる。
 
-    ᥽åɤȤϡɥݥȤʸɤѴݤΤȤǤ롣
-    ܤϴؿ mchar_define_charset () β򻲾ȤΤȡ  */
+    メソッドとは、コードポイントと文字コードを相互変換する際の方式のことである。
+    詳しくは関数 mchar_define_charset () の解説を参照のこと。  */
 /*** @{ */
 /*=*/
 /***en
@@ -896,17 +896,17 @@ CHARACTER-CODE = CODE-POINT - MIN-CODE + MIN-CHAR
     and MIN-CHAR is a value of @b Mmin_char parameter.  */
 
 /***ja
-    @brief եåȷΥ᥽åɤ򼨤ܥ.
+    @brief オフセット型のメソッドを示すシンボル.
 
-    ܥ #Moffset  <tt>"offset"</tt> Ȥ̾ʸåȤ
-    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵʲμ˽äƹԤ뤳Ȥ̣롣
+    シンボル #Moffset は <tt>"offset"</tt> という名前を持ち、文字セットの
+    @b Mmethod パラメータの値として用いられた場合には、コードポイントと文字セットの文字コードの間の変換が以下の式に従って行われることを意味する。
 
 @verbatim
-ʸ = ɥݥ - MIN-CODE + MIN-CHAR
+文字コード = コードポイント - MIN-CODE + MIN-CHAR
 @endverbatim
 
-    ǡMIN-CODE ʸåȤ @b Mmin_code ѥ᡼ͤǤꡢMIN-CHAR 
-    @b Mmin_char ѥ᡼ͤǤ롣 */
+    ここで、MIN-CODE は文字セットの @b Mmin_code パラメータの値であり、MIN-CHAR は
+    @b Mmin_char パラメータの値である。 */
 
 MSymbol Moffset;
 /*=*/
@@ -919,11 +919,11 @@ MSymbol Moffset;
     done by map looking up.  The map must be given by @b Mmapfile
     parameter.  */
 
-/***ja @brief ޥå׷Υ᥽åɤ򼨤ܥ.
+/***ja @brief マップ型のメソッドを示すシンボル.
 
-    ܥ #Mmap  <tt>"map"</tt> Ȥ̾ʸåȤ 
-    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵޥåפ򻲾Ȥ뤳ȤˤäƹԤ뤳Ȥ̣롣
-    ޥåפ @b Mmapfile ѥ᡼ȤͿʤФʤʤ */
+    シンボル #Mmap は <tt>"map"</tt> という名前を持ち、文字セットの 
+    @b Mmethod パラメータの値として用いられた場合には、コードポイントと文字セットの文字コードの間の変換がマップを参照することによって行われることを意味する。
+    マップは @b Mmapfile パラメータとして与えなければならない。 */
 
 MSymbol Mmap;
 /*=*/
@@ -949,22 +949,22 @@ CHARACTER-CODE = CODE-POINT - MIN-CODE + LOWEST-CHAR-CODE
     and LOWEST-CHAR-CODE is the lowest character code of the assigned
     code space.  */
 
-/***ja @brief ˥եΥ᥽åɤ򼨤ܥ.
+/***ja @brief ユニファイ型のメソッドを示すシンボル.
 
-    ܥ #Munify  <tt>"unify"</tt> Ȥ̾ʸåȤ 
-    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤ѴޥåפλȤȥեåȤȤ߹碌ˤäƹԤ뤳Ȥ̣롣
-    ޥåפ @b Mmapfile ѥ᡼ȤͿʤФʤʤ
-    μγʸåȤˤϡʸФϢ³륳ɥڡ줾Ƥ롣
+    シンボル #Munify は <tt>"unify"</tt> という名前を持ち、文字セットの 
+    @b Mmethod パラメータの値として用いられた場合には、コードポイントと文字セットの文字コードの間の変換が、マップの参照とオフセットの組み合わせによって行われることを意味する。
+    マップは @b Mmapfile パラメータとして与えなければならない。
+    この種の各文字セットには、全文字に対して連続するコードスペースがそれぞれ割り当てられる。
 
-    ɥݥȤޥåפ˴ޤޤƤСѴϥޥå׻ȤˤäƹԤ롣
-    ǤʤСʲμ˽
+    コードポイントがマップに含まれていれば、変換はマップ参照によって行われる。
+    そうでなければ、以下の式に従う。
 
 @verbatim
 CHARACTER-CODE = CODE-POINT - MIN-CODE + LOWEST-CHAR-CODE
 @endverbatim
     
-    ǡMIN-CODE ʸåȤ @b Mmin_code ѥ᡼ͤǤꡢ
-    LOWEST-CHAR-CODE ϳƤ줿ɥڡκǤ⾮ʸɤǤ롣
+    ここで、MIN-CODE は文字セットの @b Mmin_code パラメータの値であり、
+    LOWEST-CHAR-CODE は割り当てられたコードスペースの最も小さい文字コードである。
     */
 
 MSymbol Munify;
@@ -988,20 +988,20 @@ CHARACTER-CODE = PARENT-CODE (CODE-POINT) + SUBSET-OFFSET
     code of CODE-POINT in the parent charset, and SUBSET-OFFSET is a
     value given by @b Msubset_offset parameter.  */
 
-/***ja @brief ֥åȷΥ᥽åɤ򼨤ܥ.
+/***ja @brief サブセット型のメソッドを示すシンボル.
 
-    ܥ #Msubset  <tt>"subset"</tt> Ȥ̾ʸåȤ
-    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤʬǤ뤳Ȥ̣롣
-    ʸåȤ @b Mparents ѥ᡼ˤäͿʤƤϤʤʤ
-    ɥݥȤʸåȤʸɤδ֤ѴϡǰŪˤϰʲμ˽
+    シンボル #Msubset は <tt>"subset"</tt> という名前を持ち、文字セットの
+    @b Mmethod パラメータの値として用いられた場合には、この文字セットが別の文字セット（親文字セット）の部分集合であることを意味する。
+    親文字セットは @b Mparents パラメータによって与えられなくてはならない。
+    コードポイントと文字セットの文字コードの間の変換は、概念的には以下の式に従う。
 
 @verbatim
 CHARACTER-CODE = PARENT-CODE (CODE-POINT) + SUBSET-OFFSET
 @endverbatim
 
-     PARENT-CODE  CODE-POINT 
-    οʸåǤʸɤ֤ؿǤꡢSUBSET-OFFSET  
-    @b Msubset_offset ѥ᡼ͿͤǤ롣
+    ここで PARENT-CODE は CODE-POINT 
+    の親文字セット中での文字コードを返す擬関数であり、SUBSET-OFFSET は 
+    @b Msubset_offset パラメータで与えられる値である。
     */
 
 MSymbol Msubset;
@@ -1016,11 +1016,11 @@ MSymbol Msubset;
     must be given by @b Mparents parameter.  */
 
 /***ja
-    @brief ѡåȷΥ᥽åɤ򼨤ܥ.
+    @brief スーパーセット型のメソッドを示すシンボル.
 
-    ܥ #Msuperset  <tt>"superset"</tt> Ȥ̾ʸåȤ
-    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤξ̽Ǥ뤳Ȥ̣롣
-    ʸåȤ @b Mparents ѥ᡼ˤäͿʤƤϤʤʤ
+    シンボル #Msuperset は <tt>"superset"</tt> という名前を持ち、文字セットの
+    @b Mmethod パラメータの値として用いられた場合には、この文字セットが別の文字セット（親文字セット）の上位集合であることを意味する。
+    親文字セットは @b Mparents パラメータによって与えられなくてはならない。
     */
 
 MSymbol Msuperset;
@@ -1133,101 +1133,101 @@ MSymbol Msuperset;
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ʸåȤ.
+    @brief 文字セットを定義する.
 
-    ؿ mchar_define_charset () ϿʸåȤ 
-    $NAME Ȥ̾ĥܥͳǥǤ褦ˤ롣
-    $PLIST ʸåȤΥѥ᡼ʲΤ褦˻ꤹ롣
+    関数 mchar_define_charset () は新しい文字セットを定義し、それを 
+    $NAME という名前を持つシンボル経由でアクセスできるようにする。
+    $PLIST は定義される文字セットのパラメータを以下のように指定する。
 
     <ul>
 
-    <li>  @b Mmethod ͤܥλ
+    <li> キーが @b Mmethod で値がシンボルの時
 
-    ͤϡ#Moffset, #Mmap (ǥե), #Munify, #Msubset,
-    #Msuperset Τ줫ǤꡢʸåȤΥɥݥȤǥɡ󥳡ɤݤΥ᥽åɤꤹ롣
+    値は、#Moffset, #Mmap (デフォルト値), #Munify, #Msubset,
+    #Msuperset のいずれかであり、文字セットのコードポイントをデコード／エンコードする際のメソッドを指定する。
 
-    <li>  @b Mdimension ͤͤλ
+    <li> キーが @b Mdimension で値が整数値の時
 
-    ͤϡ1 (ǥե), 2, 3, 4 
-    Τ줫ǤꡢʸåȤΥɥݥȤμǤ롣
+    値は、1 (デフォルト値), 2, 3, 4 
+    のいずれかであり、文字セットのコードポイントの次元である。
 
-    <li>  @b Mmin_range ͤͤλ
+    <li> キーが @b Mmin_range で値が非負整数値の時
 
-    ͤϥɥݥȤκǾͤǤ롣ʤͤ N 
-    ܤΥХȤϤʸåȤΥɥݥȤ N ܤΥХȤκǾΤΤȤʤ롣
-    ǥեͤ 0 
+    値はコードポイントの最小の値である。すなわち、この値の N 
+    番目のバイトはこの文字セットのコードポイントの N 番目のバイトの最小のものとなる。
+    デフォルト値は 0 。
 
-    <li>  @b Mmax_range ͤͤλ
+    <li> キーが @b Mmax_range で値が非負整数値の時
 
-    ͤϥɥݥȤκͤǤ롣ʤͤ N 
-    ܤΥХȤϤʸåȤΥɥݥȤ N ܤΥХȤκΤΤȤʤ롣
-    ǥեͤϡɥݥȤμ 1, 2, 3, 4 λ줾
-    0xFF, 0xFFFF, 0xFFFFFF, 0xFFFFFFFF 
+    値はコードポイントの最大の値である。すなわち、この値の N 
+    番目のバイトはこの文字セットのコードポイントの N 番目のバイトの最大のものとなる。
+    デフォルト値は、コードポイントの次元が 1, 2, 3, 4 の時、それぞれ
+    0xFF, 0xFFFF, 0xFFFFFF, 0xFFFFFFFF 。
 
-    <li>  @b Mmin_code ͤͤλ
+    <li> キーが @b Mmin_code で値が非負整数値の時
 
-    ͤϤʸåȤκǾΥɥݥȤǤ롣ǥեͤ 
-    @b Mmin_range ͡
+    値はこの文字セットの最小のコードポイントである。デフォルト値は 
+    @b Mmin_range の値。
 
-    <li>  @b Mmax_code ͤͤλ
+    <li> キーが @b Mmax_code で値が非負整数値の時
 
-    ͤϤʸåȤκΥɥݥȤǤ롣ǥեͤ 
-    @b Mmax_range ͡
+    値はこの文字セットの最大のコードポイントである。デフォルト値は 
+    @b Mmax_range の値。
 
-    <li>   @b Mascii_compatible ͤܥλ
+    <li> キーが  @b Mascii_compatible で値がシンボルの時
 
-    ͤϤʸåȤ ASCII ߴǤ뤫ɤ򼨤ǥեͤ
-    #Mnil ǤиߴǤϤʤʳξϸߴǤ롣
+    値はこの文字セットが ASCII 互換であるかどうかを示す。デフォルト値の
+    #Mnil であれば互換ではなく、それ以外の場合は互換である。
 
-    <li>   @b Mfinal_byte ͤͤλ
+    <li> キーが  @b Mfinal_byte で値が整数値の時
 
-    ͤϤʸåȤ The International Registry ϿƤ 
-    @e üХ Ǥꡢ0 (ǥե) Ǥ뤫 32..127 Ǥ롣0 
-    ϿƤʤȤ̣롣
+    値はこの文字セットの The International Registry に登録されている 
+    @e 終端バイト であり、0 (デフォルト値) であるか 32..127 である。0 
+    は登録されていないことを意味する。
 
-    <li>   @b Mrevision ͤͤλ
+    <li> キーが  @b Mrevision で値が整数値の時
 
-    ͤ The International Registry ϿƤ @e revision @e
-    number Ǥꡢ0..127 Ǥ롣
-    ʸåȤϿƤʤˤϤ̵ͤ뤵롣
-    0  revision number ¸ߤʤȤ̣롣
+    値は The International Registry に登録されている @e revision @e
+    number であり、0..127 である。
+    文字セットが登録されていない場合にはこの値は無視される。
+    0 は revision number が存在しないことを意味する。
 
-    <li>   @b Mmin_char ͤͤλ
+    <li> キーが  @b Mmin_char で値が整数値の時
 
-    ͤϤʸåȤκǾʸɤǤ롣ǥեͤ 0 
+    値はこの文字セットの最小の文字コードである。デフォルト値は 0 。
 
-    <li>  @b Mmapfile ͤ M-text λ
+    <li> キーが @b Mmapfile で値が M-text の時
 
-    ᥽åɤ #Mmap  #Munify λؿ mdatabase_define () 
-    򤳤ͤ $EXTRA_INFO ȤƸƤ֤Ȥˤäơޥåԥ󥰤˴ؤǡ
-    m17n ǡ١ɲä롣
-    ʤͤϥǡե̾Ǥ롣
+    メソッドが #Mmap か #Munify の時、関数 mdatabase_define () 
+    をこの値を引数 $EXTRA_INFO として呼ぶことによって、マッピングに関するデータが
+    m17n データベースに追加される。
+    すなわち、この値はデータファイルの名前である。
 
-    ǤʤСΥѥ᡼̵뤵롣
+    そうでなければ、このパラメータは無視される。
 
-    <li>  @b Mparents ͤ plist λ
+    <li> キーが @b Mparents で値が plist の時
 
-    ᥽åɤ #Msubset ʤСͤĹ 1  plist 
-    ǤꡢͤϤʸåȤξ̽ȤʤʸåȤ򼨤ܥǤ롣
+    メソッドが #Msubset ならば、値は長さ 1 の plist 
+    であり、その値はこの文字セットの上位集合となる文字セットを示すシンボルである。
 
-    ᥽åɤ #Msuperset ʤСͤĹ 8 ʲ plist 
-    ǤꡢͤϤʸåȤβ̽ǤʸåȤ򼨤ܥǤ롣
+    メソッドが #Msuperset ならば、値は長さ 8 以下の plist 
+    であり、それらの値はこの文字セットの下位集合である文字セットを示すシンボルである。
 
-    ǤʤСΥѥ᡼̵뤵롣
+    そうでなければ、このパラメータは無視される。
 
-    <li>   @b Mdefine_coding ͤܥλ
+    <li> キーが  @b Mdefine_coding で値がシンボルの時
 
-    ʸåȤμ 1 ʤСͤ #Mnil ʳξ #Mcharset 
-    Ʊ̾ĥɷϤ롣
+    文字セットの次元が 1 ならば、値が #Mnil 以外の場合に #Mcharset 型
+    で同じ名前を持つコード系を定義する。
 
-    ǤʤСΥѥ᡼̵뤵롣
+    そうでなければ、このパラメータは無視される。
 
     </ul>
 
     @return 
-    Сmchar_define_charset()  $NAME 
-    Ȥ̾Υܥ֤Ǥʤ #Mnil ֤ѿ 
-    #merror_code ˥顼ɤꤹ롣*/
+    処理が成功すれば、mchar_define_charset() は $NAME 
+    という名前のシンボルを返す。そうでなければ #Mnil を返し、外部変数 
+    #merror_code にエラーコードを設定する。*/
 
 /***
     @errors
@@ -1348,13 +1348,13 @@ mchar_define_charset (const char *name, MPlist *plist)
     return it.  Otherwise, return #Mnil.  */
 
 /***ja
-    @brief ʸå̾褹.
+    @brief 文字セット名を解決する.
 
-    ؿ mchar_resolve_charset ()  $SYMBOL 
-    ʸåȤ򼨤ƤФ֤
+    関数 mchar_resolve_charset () は $SYMBOL 
+    が文字セットを示していればそれを返す。
 
-    ǤʤС$SYMBOL ʸå̾Ȥ줬ʸåȤ򼨤ƤƤΤ֤
-    ǤʤС#Mnil ֤ */
+    そうでなければ、$SYMBOL を文字セット名として正規化し、それが文字セットを示していていれば正規化したものを返す。
+    そうでなければ、#Mnil を返す。 */
 
 MSymbol
 mchar_resolve_charset (MSymbol symbol)
@@ -1380,11 +1380,11 @@ mchar_resolve_charset (MSymbol symbol)
     pointed to by $SYMBOLS, and returns the length of the array.  */
 
 /***ja
-    @brief ʸåȤɽ魯ܥ󤹤.
+    @brief 文字セットを表わすシンボルを列挙する.
 
-    ؿ mchar_list_charsets () 
-    ϡʸåȤ򼨤ܥ¤٤ꡢ$SYMBOLS 
-    ǥݥȤ줿ˤؤΥݥ󥿤֤Ĺ֤ */
+    関数 mchar_list_charsets () 
+    は、文字セットを示すシンボルを並べた配列を作り、$SYMBOLS 
+    でポイントされた場所にこの配列へのポインタを置き、配列の長さを返す。 */
 
 int
 mchar_list_charset (MSymbol **symbols)
@@ -1411,14 +1411,14 @@ mchar_list_charset (MSymbol **symbols)
     character code.  Otherwise it returns -1.  */
 
 /***ja
-    @brief ɥݥȤǥɤ.
+    @brief コードポイントをデコードする.
 
-    ؿ mchar_decode () ϡܥ $CHARSET_NAME Ǽʸå
-    $CODE ȤɥݥȤǥɤʸɤ롣
+    関数 mchar_decode () は、シンボル $CHARSET_NAME で示される文字セット内の
+    $CODE というコードポイントをデコードして文字コードを得る。
 
     @return
-    ǥɤСmchar_decode () ϥǥɤ줿ʸɤ֤
-    Ǥʤ -1 ֤  */
+    デコードが成功すれば、mchar_decode () はデコードされた文字コードを返す。
+    そうでなければ -1 を返す。  */
 
 /***
     @seealso
@@ -1447,14 +1447,14 @@ mchar_decode (MSymbol charset_name, unsigned code)
     code-point.  Otherwise it returns #MCHAR_INVALID_CODE.  */
 
 /***ja
-    @brief ʸɤ򥨥󥳡ɤ.
+    @brief 文字コードをエンコードする.
 
-    ؿ mchar_encode () ϡʸ $C 򥨥󥳡ɤƥܥ
-    $CHARSET_NAME Ǽʸåˤ륳ɥݥȤ롣
+    関数 mchar_encode () は、文字コード $C をエンコードしてシンボル
+    $CHARSET_NAME で示される文字セット内におけるコードポイントを得る。
 
     @return
-    󥳡ɤСmchar_encode () ϥ󡼥ɤ줿ɥݥȤ֤
-    Ǥʤ #MCHAR_INVALID_CODE ֤  */
+    エンコードが成功すれば、mchar_encode () はエンードされたコードポイントを返す。
+    そうでなければ #MCHAR_INVALID_CODE を返す。  */
 
 /***
     @seealso
@@ -1490,19 +1490,19 @@ mchar_encode (MSymbol charset_name, int c)
     variable #merror_code.  */
 
 /***ja
-    @brief ꤷʸåȤΤ٤ƤʸФƴؿƤ.
+    @brief 指定した文字セットのすべての文字に対して関数を呼ぶ.
 
-    ؿ mcharset_map_chars ()  $CHARSET_NAME 
-    Ȥ̾ʸåΤ٤ƤʸФ $FUNC Ƥ֡
-    ƤӽФϰʸǤϤʤϢ³ʸΤޤȤޤñ̤ǹԤʤ롣
+    関数 mcharset_map_chars () は $CHARSET_NAME 
+    という名前を持つ文字セット中のすべての文字に対して $FUNC を呼ぶ。
+    呼び出しは一文字毎ではなく、連続した文字のまとまり単位で行なわれる。
 
-    ؿ $FUNC ˤ$FROM, $TO, $ARG ΣϤ롣$FROM  $TO 
-     $CHARSET ʸɤϰϤꤹ롣$ARG  $FUNC_ARG 
-    ƱǤ롣
+    関数 $FUNC には$FROM, $TO, $ARG の３引数が渡される。$FROM と $TO 
+    は $CHARSET 中の文字コードの範囲を指定する。$ARG は $FUNC_ARG 
+    と同じである。
 
     @return
-     mcharset_map_chars ()  0 ֤
-    Ǥʤ -1 ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理に成功すれば mcharset_map_chars () は 0 を返す。
+    そうでなければ -1 を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /*** 
     @errors
@@ -1544,6 +1544,6 @@ mchar_map_charset (MSymbol charset_name,
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
