@@ -1,5 +1,5 @@
 /* chartab.h -- character table module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nChartable
@@ -42,21 +42,21 @@
     A chartable is a managed object.  */
 
 /***ja
-    @addtogroup m17nChartable ʸơ֥
+    @addtogroup m17nChartable 文字テーブル
 
-    @brief ʸơ֥Ȥ˴ؤ API.
+    @brief 文字テーブルとそれに関する API.
 
-    m17n 饤֥꤬ʸζ֤ϹǤ뤿ᡢʸξñ˳Ǽ褦ȤȡϵˤʤꤹŪǤ롣
-    ̾ɬפȤʤʸˤĤƤξϡϰϤʸˤΤդƤ뤳Ȥ¿
-    ʸ˴ؤƾ󤬤ˤ⡢Ϣ³ʸɤʸƱĤȤ¿
+    m17n ライブラリが扱う文字の空間は広大であるため、文字毎の情報を単純な配列に格納しようとすると、その配列は巨大になりすぎ、非実用的である。
+    しかし通常必要となる文字についての情報は、ある特定の範囲の文字にのみ付いていることが多い。
+    全文字に関して情報がある場合にも、連続した文字コードを持つ文字は同じ情報を持つことが多い。
 
-    Τ褦ʷѤʸȤղþΨŪ˳Ǽ뤿ˡ
-    m17n 饤֥ @e ʸơ֥ (chartable) ȸƤ֥֥ȤѤ롣
-    ʸơ֥ǤϤʤץꥱץʸơ֥ΰȤưȤǤ롣
-    ʸˤĤƤξϡξʸơ֥򤽤ʸΥɤǰ
-    롣  
+    このような傾向を利用して文字とその付加情報を効率的に格納するために、
+    m17n ライブラリは @e 文字テーブル (chartable) と呼ぶオブジェクトを用いる。
+    文字テーブルは配列ではないが、アプリケーションプログラムは文字テーブルを配列の一種として扱うことができる。
+    ある文字についての特定の情報は、その情報を持つ文字テーブルをその文字のコードで引くこと
+    で得られる。  
 
-    ʸơ֥ϴ֥ȤǤ롣 */
+    文字テーブルは管理下オブジェクトである。 */
 
 /*=*/
 #if !defined (FOR_DOXYGEN) || defined (DOXYGEN_INTERNAL_MODULE)
@@ -547,18 +547,18 @@ dump_sub_chartab (MSubCharTable *table, void *default_value,
 
   if (! table->contents.tables && table->default_value == default_value)
     return;
-  fprintf (stderr, "\n%s(sub%d (U+%04X U+%04X) ",
+  fprintf (mdebug__output, "\n%s(sub%d (U+%04X U+%04X) ",
 	   prefix, depth, min_char, max_char);
   if (key == Msymbol)
     {
       if (table->default_value)
-	fprintf (stderr, "(default %s)",
+	fprintf (mdebug__output, "(default %s)",
 		 ((MSymbol) table->default_value)->name);
       else
-	fprintf (stderr, "(default nil)");
+	fprintf (mdebug__output, "(default nil)");
     }
   else
-    fprintf (stderr, "(default #x%X)", (unsigned) table->default_value);
+    fprintf (mdebug__output, "(default #x%p)", table->default_value);
 
   default_value = table->default_value;
   if (table->contents.tables)
@@ -575,23 +575,24 @@ dump_sub_chartab (MSubCharTable *table, void *default_value,
 	    if (val == default_value)
 	      continue;
 	    default_value = *val;
-	    fprintf (stderr, "\n%s  (U+%04X", prefix, min_char);
+	    fprintf (mdebug__output, "\n%s  (U+%04X", prefix, min_char);
 	    while (i + 1 < chartab_slots[depth]
 		   && val[1] == default_value)
 	      i++, val++, min_char++;
-	    fprintf (stderr, "-U+%04X ", min_char);
+	    fprintf (mdebug__output, "-U+%04X ", min_char);
 	    if (key == Msymbol)
 	      {
 		if (default_value)
-		  fprintf (stderr, "%s)", ((MSymbol) default_value)->name);
+		  fprintf (mdebug__output, "%s)",
+			   ((MSymbol) default_value)->name);
 		else
-		  fprintf (stderr, "nil)");
+		  fprintf (mdebug__output, "nil)");
 	      }
 	    else
-	      fprintf (stderr, " #xx%X)", (unsigned) default_value);
+	      fprintf (mdebug__output, " #x%p)", default_value);
 	  }
     }
-  fprintf (stderr, ")");
+  fprintf (mdebug__output, ")");
 }
 
 
@@ -621,9 +622,8 @@ mchartable__lookup (MCharTable *table, int c, int *next_c, int default_p)
 
 /* External API */
 
-/*** @addtogroup m17nChartable */
-/*** @{ */
-/*=*/
+/*** @addtogroup m17nChartable
+     @{ */
 
 /***en
     @brief Symbol whose name is "char-table".
@@ -631,9 +631,9 @@ mchartable__lookup (MCharTable *table, int c, int *next_c, int default_p)
     The symbol @c Mchar_table has the name <tt>"char-table"</tt>.  */
 
 /***ja
-    @brief "char-table" Ȥ̾ĥܥ.
+    @brief "char-table" という名前を持つシンボル.
 
-    ܥ @c Mchar_table ̾ <tt>"char-table"</tt> ġ
+    シンボル @c Mchar_table は名前 <tt>"char-table"</tt> を持つ。
     */
 
 MSymbol Mchar_table;
@@ -654,16 +654,16 @@ MSymbol Mchar_table;
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ʸơ֥.
+    @brief 新しい文字テーブルを作る.
 
-    ؿ mchartable () ϥ $KEY ǤΥǥեͤ 
-    $DEFAULT_VALUE Ǥ뿷ʸơ֥롣⤷ $KEY 
-    ǤСΥơ֥Ǥϡʥǥեͤޤơ˴֥Ȥ 
-    NULL Τ줫Ǥ롣
+    関数 mchartable () はキーが $KEY で要素のデフォルト値が 
+    $DEFAULT_VALUE である新しい文字テーブルを作る。もし $KEY 
+    が管理キーであれば、このテーブルの要素は（デフォルト値を含めて）管理下オブジェクトか 
+    NULL のいずれかである。
 
     @return
-     mchartable () Ϻ줿ʸơ֥ؤΥݥ󥿤֤
-    Ԥ @c NULL ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば mchartable () は作成された文字テーブルへのポインタを返す。
+    失敗した場合は @c NULL を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 MCharTable *
 mchartable (MSymbol key, void *default_value)
@@ -727,12 +727,12 @@ mchartable_max_char (MCharTable *table)
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ʸơ֥ʸ˳Ƥ줿֤ͤ.
+    @brief 文字テーブル中で文字に割り当てられた値を返す.
 
-    ؿ mchartable_lookup () ʸơ֥ $TABLE ʸ $C 
-    ˳Ƥ줿֤ͤ$C ФŪͤʤС$TABLE 
-    Υǥե֤ͤ$C ʸǤʤСmchartable_lookup ()  
-    @c NULL ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    関数 mchartable_lookup () は文字テーブル $TABLE 中で文字 $C 
+    に割り当てられた値を返す。$C に対する明示的な値がなければ、$TABLE 
+    のデフォルト値を返す。$C が妥当な文字でなければ、mchartable_lookup () は 
+    @c NULL を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -765,14 +765,14 @@ mchartable_lookup (MCharTable *table, int c)
     variable #merror_code.  */
 
 /***ja
-    @brief ʸơ֥Ǥʸͤꤹ.
+    @brief 文字テーブル中での文字の値を設定する.
 
-    ؿ mchartable_set () ϡʸơ֥ $TABLE ʸ $C 
-     $VAL Ƥ롣
+    関数 mchartable_set () は、文字テーブル $TABLE 中の文字 $C 
+    に値 $VAL を割り当てる。
 
     @return
-    Сmchartable_set ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば、mchartable_set () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -838,16 +838,16 @@ mchartable_set (MCharTable *table, int c, void *val)
     mchartable_set_range () returns immediately without an error.  */
 
 /***ja
-    @brief ϰϤʸͤꤹ.
+    @brief 指定範囲の文字に値を設定する.
 
-    ؿ mchartable_set_range () ϡʸơ֥ $TABLE  $FROM 
-     $TO ޤǡξüޤˤʸˡͤȤ $VAL ꤹ롣
+    関数 mchartable_set_range () は、文字テーブル $TABLE 中の $FROM 
+    から $TO まで（両端を含む）の文字に、値として $VAL を設定する。
 
     @return
-     mchartable_set_range ()  0 ֤Ǥʤ 
-    -1 ֤ѿ #merror_code ˥顼ɤꤹ롣$FROM  
-    $TO 礭Ȥˤϡ mchartable_set_range () 
-    ϲ⤻顼ⵯʤ  */
+    処理が成功すれば mchartable_set_range () は 0 を返す。そうでなければ 
+    -1 を返し、外部変数 #merror_code にエラーコードを設定する。$FROM が 
+    $TO より大きいときには、 mchartable_set_range () 
+    は何もせず、エラーも起こさない。  */
 
 /***
     @errors
@@ -891,12 +891,12 @@ mchartable_set_range (MCharTable *table, int from, int to, void *val)
     to -1.  */
 
 /***ja
-    @brief ͤǥեȤȰۤʤʸõ.
+    @brief 値がデフォルトと異なる文字を探す.
 
-    ؿ mchartable_range () ʸơ֥ $TABLE ǡ$TABLE 
-    ΥǥեͰʳͤĺǽȺǸʸõ줾 $FROM 
-     $TO ꤹ롣٤ƤʸͤȤƥǥեͤȤäƤˤ
-    $FROM  $TO  -1ꤹ롣  */
+    関数 mchartable_range () は文字テーブル $TABLE 中で、$TABLE 
+    のデフォルト値以外の値を持つ最初と最後の文字を探し、それぞれを $FROM 
+    と $TO に設定する。すべての文字が値としてデフォルト値をとっている場合には
+    $FROM と $TO を -1に設定する。  */
 
 void
 mchartable_range (MCharTable *table, int *from, int *to)
@@ -935,24 +935,24 @@ mchartable_range (MCharTable *table, int *from, int *to)
     This function always returns 0.  */
 
 /***ja
-    @brief ʸơ֥ʸФƻδؿƤ.
+    @brief 文字テーブル中の文字に対して指定の関数を呼ぶ.
 
-    ؿ mchartable_map () ϡʸơ֥ $TABLE ʸФƴؿ
-    $FUNC Ƥ֡$TABLE Ǥͤ $IGNORE 
-    ǤʸˤĤƤϴؿƤӽФԤʤʤ$IGNORE ʸͤӤ 
-    @c == ǹԤʤΤǡʸƥݥ󥿤Ȥݤˤդפ롣
+    関数 mchartable_map () は、文字テーブル $TABLE 中の文字に対して関数
+    $FUNC を呼ぶ。ただし$TABLE 中でも値が $IGNORE 
+    である文字については関数呼び出しを行なわない。$IGNORE と文字の値の比較は 
+    @c == で行なうので、文字列リテラルやポインタを使う際には注意を要する。
 
-    mchartable_map () ϡʸȤ $FUNC 
-    Ƥ֤ΤǤϤʤؿƤӽФβŬ褦Ȥ롣
-    ʤϢ³ʸƱͤäƤˤϡʸΤޤȤޤΤˤĤư٤δؿƤӽ
-    Ԥʤʤ
+    mchartable_map () は、一文字ごとに $FUNC 
+    を呼ぶのではなく、関数呼び出しの回数を最適化しようとする。
+    すなわち、連続した文字が同じ値を持っていた場合には、その文字のまとまり全体について一度の関数呼び出
+    ししか行なわない。
 
-    ʸΤޤȤޤ礭ˤ餺$FUNC  $FROM, $TO, $VAL, $ARG 
-    ΣǸƤФ롣$FROM  $TO ξüޤˤ $VAL 
-    ͤȤƻʸϰϤ򼨤$ARG  $FUNC_ARG ΤΤǤ롣
+    文字のまとまりの大きさにかかわらず、$FUNC は $FROM, $TO, $VAL, $ARG 
+    の４引数で呼ばれる。$FROM と $TO （両端を含む）は $VAL 
+    を値として持つ文字の範囲を示し、$ARG は $FUNC_ARG そのものである。
 
     @return
-    δؿϾ0֤  */
+    この関数は常に0を返す。  */
 
 int
 mchartable_map (MCharTable *table, void *ignore,
@@ -975,29 +975,31 @@ mchartable_map (MCharTable *table, void *ignore,
     @brief Dump a chartable.
 
     The mdebug_dump_chartab () function prints a chartable $TABLE in a
-    human readable way to the stderr.  $INDENT specifies how many
-    columns to indent the lines but the first one.
+    human readable way to the stderr or to what specified by the
+    environment variable MDEBUG_OUTPUT_FILE.  $INDENT specifies how
+    many columns to indent the lines but the first one.
 
     @return
     This function returns $TABLE.  */
 
 /***ja
-    @brief ʸơ֥פ.
+    @brief 文字テーブルをダンプする.
 
-    ؿ mdebug_dump_chartab () ʸơ֥ $TABLE  stderr 
-    ˿ʹ֤˲ɤʷǰ롣$INDENT ϣܰʹߤΥǥȤꤹ롣
+    関数 mdebug_dump_chartab () は文字テーブル $TABLE を標準エラー出力
+    もしくは環境変数 MDEBUG_DUMP_FONT で指定されたファイルに人間に可読
+    な形で印刷する。$INDENT は２行目以降のインデントを指定する。
 
     @return
-    δؿ $TABLE ֤  */
+    この関数は $TABLE を返す。  */
 
 MCharTable *
 mdebug_dump_chartab (MCharTable *table, int indent)
 {
-  fprintf (stderr, "(chartab (U+%04X U+%04X)",
+  fprintf (mdebug__output, "(chartab (U+%04X U+%04X)",
 	   table->min_char, table->max_char);
   dump_sub_chartab (&table->subtable, table->subtable.default_value,
 		    table->key, indent + 2);
-  fprintf (stderr, ")");
+  fprintf (mdebug__output, ")");
   return table;
 }
 
@@ -1005,6 +1007,6 @@ mdebug_dump_chartab (MCharTable *table, int indent)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
