@@ -1,5 +1,5 @@
 /* font-ft.c -- FreeType interface sub-module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #include "config.h"
 
@@ -66,6 +66,7 @@ static FT_Library ft_library;
 
 #ifdef HAVE_OTF
 static OTF *invalid_otf = (OTF *) "";
+static OTF *get_otf (MFLTFont *font, FT_Face *ft_face);
 #endif /* HAVE_OTF */
 
 typedef struct
@@ -370,11 +371,12 @@ fc_decode_prop (int val, FC_vs_M17N_font_prop *table, int size)
 	  break;
       i++;
     }
-  else
+  else if (val > table[i].fc_value)
     {
-      for (; i < size; i++)
-	if (val <= table[i].fc_value)
+      for (i++; i < size; i++)
+	if (val < table[i].fc_value)
 	  break;
+      i--;
     }
   return table[i].sym;
 }
@@ -695,7 +697,7 @@ ft_init_font_list (void)
   SAFE_FREE (path);
 }
 
-/* Return 1 iff the font pointed by FT_INFO has all characters in
+/* Return 1 if the font pointed by FT_INFO has all characters in
    CHAR_LIST.  */
 
 static int
@@ -2091,7 +2093,7 @@ ft_encapsulate (MFrame *frame, MSymbol data_type, void *data)
   ft_rfont->ft_face = ft_face;
   ft_rfont->face_encapsulated = 1;
 
-  MDEBUG_DUMP (" [FONT-FT] encapsulating ", (char *) ft_face->family_name,);
+  MDEBUG_PRINT1 (" [FONT-FT] encapsulating %s", (char *) ft_face->family_name);
 
   MSTRUCT_CALLOC (rfont, MERROR_FONT_FT);
   rfont->id = ft_info->font.file;
@@ -2141,6 +2143,74 @@ ft_close (MRealizedFont *rfont)
   free (rfont);
 }
 
+/* See the comment of parse_otf_command (m17n-flt.c).  */
+
+static int 
+ft_check_otf (MFLTFont *font, MFLTOtfSpec *spec)
+{
+#define FEATURE_NONE(IDX) (! spec->features[IDX])
+
+#define FEATURE_ANY(IDX)	\
+  (spec->features[IDX]		\
+   && spec->features[IDX][0] == 0xFFFFFFFF && spec->features[IDX][1] == 0)
+
+#ifdef HAVE_OTF
+  OTF_Tag *tags;
+  int i, n, negative;
+  OTF *otf = get_otf (font, NULL);
+  
+  if (FEATURE_ANY (0) && FEATURE_ANY (1))
+    /* Return 1 if any of GSUB or GPOS support the script (and language).  */
+    return (otf
+	    && (OTF_check_features (otf, 0, spec->script, spec->langsys,
+				    NULL, 0) > 0
+		|| OTF_check_features (otf, 1, spec->script, spec->langsys,
+				       NULL, 0) > 0));
+
+  for (i = 0; i < 2; i++)
+    if (! FEATURE_ANY (i))
+      {
+	if (FEATURE_NONE (i))
+	  {
+	    if (otf
+		&& OTF_check_features (otf, i == 0, spec->script, spec->langsys,
+				       NULL, 0) > 0)
+	      return 0;
+	    continue;
+	  }
+	if (spec->features[i][0] == 0xFFFFFFFF)
+	  {
+	    if (! otf
+		|| OTF_check_features (otf, i == 0, spec->script, spec->langsys,
+				       NULL, 0) <= 0)
+	      continue;
+	  }
+	else if (! otf)
+	  return 0;
+	for (n = 1; spec->features[i][n]; n++);
+	tags = alloca (sizeof (OTF_Tag) * n);
+	for (n = 0, negative = 0; spec->features[i][n]; n++)
+	  {
+	    if (spec->features[i][n] == 0xFFFFFFFF)
+	      negative = 1;
+	    else if (negative)
+	      tags[n - 1] = spec->features[i][n] | 0x80000000;
+	    else
+	      tags[n] = spec->features[i][n];
+	  }
+	if (OTF_check_features (otf, i == 0, spec->script, spec->langsys,
+				tags, n - negative) != 1)
+	  return 0;
+      }
+  return 1;
+
+#endif	/* HAVE_OTF */
+  return (FEATURE_NONE (0) ? (FEATURE_NONE (1) || FEATURE_ANY (1))
+	  : (FEATURE_NONE (1) && FEATURE_ANY (0)));
+}
+
+#ifdef HAVE_OTF
+
 static OTF *
 get_otf (MFLTFont *font, FT_Face *ft_face)
 {
@@ -2165,45 +2235,6 @@ get_otf (MFLTFont *font, FT_Face *ft_face)
   return (otf == invalid_otf ? NULL : otf);
 }
 
-static int 
-ft_check_otf (MFLTFont *font, MFLTOtfSpec *spec)
-{
-#ifdef HAVE_OTF
-  OTF_Tag *tags;
-  int i, n, negative;
-  OTF *otf = get_otf (font, NULL);
-
-  if (! otf)
-    goto not_otf;
-  for (i = 0; i < 2; i++)
-    {
-      if (! spec->features[i])
-	continue;
-      for (n = 0; spec->features[i][n]; n++);
-      tags = alloca (sizeof (OTF_Tag) * n);
-      for (n = 0, negative = 0; spec->features[i][n]; n++)
-	{
-	  if (spec->features[i][n] == 0xFFFFFFFF)
-	    negative = 1;
-	  else if (negative)
-	    tags[n - 1] = spec->features[i][n] | 0x80000000;
-	  else
-	    tags[n] = spec->features[i][n];
-	}
-      if (n - negative > 0
-	  && OTF_check_features (otf, i == 0, spec->script, spec->langsys,
-				 tags, n - negative) != 1)
-	return 0;
-    }
-  return 1;
-#endif	/* HAVE_OTF */
- not_otf:
-  return ((! spec->features[0] || spec->features[0][0] == 0xFFFFFFFF)
-	  && (! spec->features[1] || spec->features[1][0] == 0xFFFFFFFF));
-}
-
-#ifdef HAVE_OTF
-
 #define DEVICE_DELTA(table, size)				\
   (((size) >= (table).StartSize && (size) <= (table).EndSize)	\
    ? (table).DeltaValue[(size) - (table).StartSize] << 6	\
@@ -2236,6 +2267,8 @@ adjust_anchor (OTF_Anchor *anchor, FT_Face ft_face,
 }
 #endif	/* HAVE_OTF */
 
+#ifdef HAVE_OTF
+
 static int 
 ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	      MFLTGlyphString *in, int from, int to,
@@ -2243,7 +2276,6 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 {
   int len = to - from;
   int i, j, gidx;
-#ifdef HAVE_OTF
   MGlyph *in_glyphs = (MGlyph *) (in->glyphs);
   MGlyph *out_glyphs = out ? (MGlyph *) (out->glyphs) : NULL;
   OTF *otf;
@@ -2291,14 +2323,18 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	}
     }
 
-  otf_gstring.size = otf_gstring.used = len;
-  otf_gstring.glyphs = (OTF_Glyph *) malloc (sizeof (OTF_Glyph) * len);
-  memset (otf_gstring.glyphs, 0, sizeof (OTF_Glyph) * len);
+  /* Extra room from pseudo glyphs.  OTF_drive_features () may need
+     more rooms.  In that case, otf_gstring.glyphs is reallocated.  */
+  otf_gstring.size = len * 2;
+  if (! MTABLE_CALLOC_SAFE (otf_gstring.glyphs, otf_gstring.size))
+    MERROR (MERROR_MEMORY, -1);
   for (i = 0; i < len; i++)
     {
       otf_gstring.glyphs[i].c = ((MGlyph *)in->glyphs)[from + i].g.c & 0x11FFFF;
       otf_gstring.glyphs[i].glyph_id = ((MGlyph *)in->glyphs)[from + i].g.code;
+      otf_gstring.glyphs[i].positioning_type = ((MGlyph *)in->glyphs)[from + i].libotf_positioning_type;
     }
+  otf_gstring.used = len;
 
   OTF_drive_gdef (otf, &otf_gstring);
   gidx = out ? out->used : from;
@@ -2308,9 +2344,15 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
       OTF_Feature *features;
       MGlyph *g;
 
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+      if (OTF_drive_gsub_features (otf, &otf_gstring, script, langsys,
+				   gsub_features) < 0)
+	goto simple_copy;
+#else
       if (OTF_drive_gsub_with_log (otf, &otf_gstring, script, langsys,
 				   gsub_features) < 0)
 	goto simple_copy;
+#endif
       features = otf->gsub->FeatureList.Feature;
       if (out)
 	{
@@ -2319,9 +2361,15 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	  for (i = 0, otfg = otf_gstring.glyphs, g = out_glyphs + gidx;
 	       i < otf_gstring.used; i++, otfg++, g++, out->used++)
 	    {
-	      int feature_idx = otfg->positioning_type >> 4;
 	      int j;
 	      int min_from, max_to;
+	      int feature_idx;
+
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+	      feature_idx = OTF_POSITIONING_TYPE_GET_FEATURE (otfg);
+#else
+	      feature_idx = otfg->positioning_type >> 4;
+#endif
 
 	      *g = in_glyphs[from + otfg->f.index.from];
 	      min_from = g->g.from, max_to = g->g.to;
@@ -2358,8 +2406,13 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	  for (i = 0, otfg = otf_gstring.glyphs; i < otf_gstring.used;
 	       i++, otfg++)
 	    {
-	      int feature_idx = otfg->positioning_type >> 4;
+	      int feature_idx;
 
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+	      feature_idx = OTF_POSITIONING_TYPE_GET_FEATURE (otfg);
+#else
+	      feature_idx = otfg->positioning_type >> 4;
+#endif
 	      if (feature_idx)
 		{
 		  tag = features[feature_idx - 1].FeatureTag;
@@ -2386,9 +2439,15 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
       OTF_Feature *features;
       MGlyph *g;
 
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+      if (OTF_drive_gpos_features (otf, &otf_gstring, script, langsys,
+				   gpos_features) < 0)
+	return to;
+#else
       if (OTF_drive_gpos_with_log (otf, &otf_gstring, script, langsys,
 				   gpos_features) < 0)
 	return to;
+#endif
       features = otf->gpos->FeatureList.Feature;
       if (out)
 	{
@@ -2403,7 +2462,15 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	    {
 	      MGlyph *prev;
 	      int adjust_idx = otfg->glyph_id ? j : j - 1;
-	      int feature_idx = otfg->positioning_type >> 4;
+	      int positioning_type, feature_idx;
+
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+	      positioning_type = OTF_POSITIONING_TYPE_GET_FORMAT (otfg);
+	      feature_idx = OTF_POSITIONING_TYPE_GET_FEATURE (otfg);
+#else
+	      positioning_type = otfg->positioning_type & 0xF;
+	      feature_idx = otfg->positioning_type >> 4;
+#endif
 
 	      if (feature_idx)
 		{
@@ -2411,7 +2478,8 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 		  tag = PACK_OTF_TAG (tag);
 		  g->g.internal = (g->g.internal & ~0x1FFFFFFF) | tag;
 		}
-	      switch (otfg->positioning_type & 0xF)
+
+	      switch (positioning_type)
 		{
 		case 0:
 		  break;
@@ -2460,7 +2528,18 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 		  if (! mark)
 		    break;
 		  prev = mark;
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+		  {
+		    int distance = OTF_POSITIONING_TYPE_GET_MARKDISTANCE (otfg);
 
+		    if (distance > 0)
+		      {
+			prev = g - distance;
+			if (prev < out_glyphs)
+			  prev = mark;
+		      }
+		  }
+#endif
 		label_adjust_anchor:
 		  {
 		    int base_x, base_y, mark_x, mark_y;
@@ -2518,8 +2597,13 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	       i++, otfg++)
 	    if (otfg->positioning_type & 0xF)
 	      {
-		int feature_idx = otfg->positioning_type >> 4;
+		int feature_idx;
 
+#ifdef OTF_POSITIONING_TYPE_GET_FORMAT
+		feature_idx = OTF_POSITIONING_TYPE_GET_FEATURE (otfg);
+#else
+		feature_idx = otfg->positioning_type >> 4;
+#endif
 		if (feature_idx)
 		  {
 		    tag = features[feature_idx - 1].FeatureTag;
@@ -2540,7 +2624,6 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
  simple_copy:
   if (otf_gstring.glyphs)
     free (otf_gstring.glyphs);
-#endif	/* HAVE_OTF */
   if (out)
     {
       if (out->allocated < out->used + len)
@@ -2553,6 +2636,29 @@ ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
   return to;
 }
 
+#else  /* not HAVE_OTF */
+
+static int 
+ft_drive_otf (MFLTFont *font, MFLTOtfSpec *spec,
+	      MFLTGlyphString *in, int from, int to,
+	      MFLTGlyphString *out, MFLTGlyphAdjustment *adjustment)
+{
+  int len = to - from;
+  if (out)
+    {
+      if (out->allocated < out->used + len)
+	return -2;
+      font->get_metrics (font, in, from, to);
+      memcpy ((MGlyph *)out->glyphs + out->used, (MGlyph *) in->glyphs + from,
+	      sizeof (MGlyph) * len);
+      out->used += len;
+    }
+  return to;
+}
+
+#endif	/* not HAVE_OTF */
+
+
 static int 
 ft_try_otf (MFLTFont *font, MFLTOtfSpec *spec,
 	    MFLTGlyphString *in, int from, int to)
