@@ -1,5 +1,5 @@
 /* fontset.c -- fontset module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nFontset
@@ -37,17 +37,17 @@
 
 /***ja @addtogroup m17nFontset 
 
-    @brief եȥåȤʸեȤؤбդԤ֥ȤǤ.
+    @brief フォントセットは文字からフォントへの対応付けを行うオブジェクトである.
 
-    @e եȥå  @c MFontset Υ֥ȤǤ롣M-text 
-    ɽκݡեȥåȤϰʲξѤ M-text 
-    θġʸˤɤΥեȤѤ뤫뵬§Ϳ롣
+    @e フォントセット は @c MFontset 型のオブジェクトである。M-text 
+    の表示の際、フォントセットは以下の情報を用いて M-text 
+    中の個々の文字にどのフォントを用いるか決める規則を与える。
 
-    @li ʸʸץѥƥ "ץ"
-    @li ʸΥƥȥץѥƥ ""
-    @li ʸΥƥȥץѥƥ "ʸå"
+    @li 文字の文字プロパティ "スクリプト"
+    @li 文字のテキストプロパティ "言語"
+    @li 文字のテキストプロパティ "文字セット"
 
-    ξ󤬤ɤΤ褦Ѥ뤫 mdraw_text () 򻲾ȤΤȡ
+    これらの情報がどのように用いられるかは mdraw_text () の説明を参照のこと。
 
     */
 
@@ -300,13 +300,15 @@ realize_fontset_elements (MFrame *frame, MRealizedFontset *realized)
 {
   MFontset *fontset = realized->fontset;
   MPlist *per_script, *per_charset, *font_group;
-  MPlist *plist, *pl, *p;
+  MPlist *plist, *p;
 
   realized->per_script = per_script = mplist ();
   /* The actual elements of per_script are realized on demand.  */
 #if 0
   MPLIST_DO (plist, fontset->per_script)
     {
+      MPlist *pl;
+
       per_lang = mplist ();
       per_script = mplist_add (per_script, MPLIST_KEY (plist), per_lang);
       MPLIST_DO (pl, MPLIST_PLIST (plist))
@@ -321,11 +323,11 @@ realize_fontset_elements (MFrame *frame, MRealizedFontset *realized)
 #endif
 
   realized->per_charset = per_charset = mplist ();
-  MPLIST_DO (pl, fontset->per_charset)
+  MPLIST_DO (plist, fontset->per_charset)
     {
       font_group = mplist ();
       per_charset = mplist_add (per_charset, MPLIST_KEY (plist), font_group);
-      MPLIST_DO (p, MPLIST_PLIST (pl))
+      MPLIST_DO (p, MPLIST_PLIST (plist))
 	font_group = mplist_add (font_group, MPLIST_KEY (p), MPLIST_VAL (p));
     }
   realized->fallback = font_group = mplist ();
@@ -1001,21 +1003,21 @@ mfontset__get_font (MFrame *frame, MFontset *fontset,
     This function returns a pointer to the found or newly created
     fontset.  */
 /***ja 
-    @brief եȥåȤ֤.
+    @brief フォントセットを返す.
 
-    ؿ mfontset () ̾ $NAME ĥեȥåȥ֥ȤؤΥݥ󥿤֤ 
-    $NAME  @c NULL ʤСǥեȥեȥåȤؤΥݥ󥿤֤
+    関数 mfontset () は名前 $NAME を持つフォントセットオブジェクトへのポインタを返す。 
+    $NAME が @c NULL ならば、デフォルトフォントセットへのポインタを返す。
 
-    $NAME Ȥ̾ĥեȥåȤʤСΤ롣κݡ
-    m17n ǡ١ \<@c fontset, $NAME\> 
-    ȤǡСեȥåȤϤΥǡ˱äƽ롣
-    ʤСΤޤޤˤ롣
+    $NAME という名前を持つフォントセットがなければ、新しいものが作られる。その際、
+    m17n データベースに \<@c fontset, $NAME\> 
+    というデータがあれば、フォントセットはそのデータに沿って初期化される。
+    なければ、空のままにされる。
 
-    ޥ M17N_INIT () ϥǥեȤΥեȥåȤ롣ץꥱץ
-    mframe () ƸƤ֤ޤǤδ֤ϥǥեȥեȥåȤѹ뤳ȤǤ롣
+    マクロ M17N_INIT () はデフォルトのフォントセットを作る。アプリケーションプログラムは
+    mframe () を初めて呼ぶまでの間はデフォルトフォントセットを変更することができる。
 
     @return
-    δؿϸĤä뤤ϺäեȥåȤؤΥݥ󥿤֤
+    この関数は見つかった、あるいは作ったフォントセットへのポインタを返す。
      */
 
 MFontset *
@@ -1060,9 +1062,9 @@ mfontset (char *name)
 
     The mfontset_name () function returns the name of fontset $FONTSET.  */
 /***ja
-    @brief եȥåȤ֤̾.
+    @brief フォントセットの名前を返す.
 
-    ؿ mfontset_name () ϥեȥå $FONTSET ֤̾  */
+    関数 mfontset_name () はフォントセット $FONTSET の名前を返す。  */
 MSymbol
 mfontset_name (MFontset *fontset)
 {
@@ -1079,12 +1081,12 @@ mfontset_name (MFontset *fontset)
     not be a name of existing fontset.  In such case, this function
     returns NULL without making a copy.  */
 /***ja
-    @brief եȥåȤΥԡ.
+    @brief フォントセットのコピーを作る.
 
-    ؿ mfontset_copy () ϥեȥå $FONTSET Υԡäơ̾
-    $NAME ͿΥԡؤΥݥ󥿤֤$NAME 
-    ϴ¸ΥեȥåȤ̾ǤäƤϤʤʤΤ褦ʾˤϥԡ餺
-    NULL ֤  */
+    関数 mfontset_copy () はフォントセット $FONTSET のコピーを作って、名前
+    $NAME を与え、そのコピーへのポインタを返す。$NAME 
+    は既存のフォントセットの名前であってはならない。そのような場合にはコピーを作らずに
+    NULL を返す。  */
 
 MFontset *
 mfontset_copy (MFontset *fontset, char *name)
@@ -1198,40 +1200,40 @@ mfontset_copy (MFontset *fontset, char *name)
     variable #merror_code.  */
 
 /***ja
-    @brief եȥåȤƤѹ.
+    @brief フォントセットの内容を変更する.
 
-    ؿ mfontset_modify_entry () ϡ$LANGUAGE  $SCRIPT Ȥ߹碌ޤ
-    $CHARSET Ф $FONT ΥԡȤ褦ˡեȥå $FONTSET ꤹ롣
+    関数 mfontset_modify_entry () は、$LANGUAGE と $SCRIPT の組み合わせ、または
+    $CHARSET に対して $FONT のコピーを使うように、フォントセット $FONTSET を設定する。
 
-    եȥåγƥեȤϡΥץȤȸΥڥʸåȡܥ
-    @c Mnil Τ줫ȴϢդƤ롣ƱΤȴϢդ줿եȤϥ롼פ롣
+    フォントセット中の各フォントは、特定のスクリプトと言語のペア、特定の文字セット、シンボル
+    @c Mnil のいずれかと関連付けられている。同じものと関連付けられたフォントはグループを構成する。
 
-    $SCRIPT  @c Mnil Ǥ뤫ץȤꤹ륷ܥǤ롣
-    ܥǤˤϡ$LANGUAGE ϸꤹ륷ܥ뤫 @c
-    Mnil Ǥꡢ$FONT the $SCRIPT / $LANGUAGE ڥ˴Ϣդ롣
+    $SCRIPT は @c Mnil であるか、スクリプトを特定するシンボルである。
+    シンボルである場合には、$LANGUAGE は言語を特定するシンボルか @c
+    Mnil であり、$FONT はthe $SCRIPT / $LANGUAGE ペアに関連付けられる。
 
-    $CHARSET  @c Mnil Ǥ뤫ʸåȥ֥ȤɽܥǤ롣
-    ܥǤˤ $FONT ϤʸåȤȴϢդ롣
+    $CHARSET は @c Mnil であるか、文字セットオブジェクトを表すシンボルである。
+    シンボルである場合には $FONT はその文字セットと関連付けられる。
 
-    $SCRIPT  $CHARSET  @c Mnil Ǥʤˤ $FONT 
-    Υԡĺ졢줾 $SCRIPT / $LANGUAGE 
-    ڥʸåȤ˴Ϣդ롣
+    $SCRIPT と $CHARSET の双方が @c Mnil でない場合には $FONT 
+    のコピーが２つ作られ、それぞれ $SCRIPT / $LANGUAGE 
+    ペアと文字セットに関連付けられる。
 
-    $SCRIPT  $CHARSET  @c Mnil ʤС $FONT  @c Mnil 
-    ȴϢդ롣μΥեȤ @e fallback @e font ȸƤФ롣
+    $SCRIPT と $CHARSET の双方が @c Mnil ならば、 $FONT は @c Mnil 
+    と関連付けられる。この種のフォントは @e fallback @e font と呼ばれる。
 
-     $HOW  $FONT ͥ٤ꤹ롣$HOW ʤС$FONT 
-    ƱΤȴϢդ줿롼Ǻǹͥ٤ġ$HOW 
-    ʤСͥ٤ġ$HOW  0 ʤС$FONT 
-    ϴϢդ줿ΤФͣѲǽʥեȤȤʤꡢ¾ΥեȤϥ롼פ롣
+    引数 $HOW は $FONT の優先度を指定する。$HOW が正ならば、$FONT 
+    は同じものと関連付けられたグループ中で最高の優先度を持つ。$HOW 
+    が負ならば、最低の優先度を持つ。$HOW が 0 ならば、$FONT 
+    は関連付けられたものに対する唯一の利用可能なフォントとなり、他のフォントはグループから取り除かれる。
 
-    $LAYOUTER_NAME  @c Mnil Ǥ뤫@ref mdbFLT 
-    ʥեȥ쥤ȥơ֥ˤ򼨤ܥǤ롣ܥǤС$FONT Ѥ
-    M-text ɽݤˤϡΥեȥ쥤ȥơ֥Ȥäʸ󤫤饰ե롣
+    $LAYOUTER_NAME は @c Mnil であるか、@ref mdbFLT 
+    （フォントレイアウトテーブル）を示すシンボルである。シンボルであれば、$FONT を用いて
+    M-text を表示する際には、そのフォントレイアウトテーブルを使って文字列からグリフコード列を生成する。
 
     @return 
-    Ȥmfontset_modify_entry ()  0 ֤
-    ԤȤ -1 ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功したとき、mfontset_modify_entry () は 0 を返す。
+    失敗したときは -1 を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -1343,47 +1345,47 @@ mfontset_modify_entry (MFontset *fontset,
     It returns a plist describing the contents of a fontset.  The
     plist should be freed by m17n_object_unref ().  */
 /***ja
-    @brief եȥåȤ򸡺.
+    @brief フォントセットを検索する.
 
-    ؿ mfontset_lookup ()  $FONTSET 򸡺$FONTSET 
-    ƤΤꤷץȡ졢ʸåȤбʬɽ
-    plist ֤
+    関数 mfontset_lookup () は $FONTSET を検索し、$FONTSET 
+    の内容のうち指定したスクリプト、言語、文字セットに対応する部分を表す
+    plist を返す。
 
-    $SCRIPT  @c Mt ʤС֤ plist 
-    ΥϥեȤꤵƤ륹ץ̾ΥܥǤꡢͤ
-    NULL Ǥ롣
+    $SCRIPT が @c Mt ならば、返す plist 
+    のキーはフォントが指定されているスクリプト名のシンボルであり、値は
+    NULL である。
 
-    $SCRIPT ץ̾ΥܥǤС֤ 
-    plist  $LANGUAGEˤäޤ롣
+    $SCRIPT がスクリプト名のシンボルであれば、返す 
+    plist は $LANGUAGEによって定まる。
     
-    @li $LANGUAGE  @c Mt ʤСplist 
-    ΥϥեȤꤵƤ̾ΥܥǤꡢͤ
-    NULL Ǥ롣 @c Mt
-    Ǥ뤳Ȥ⤢ꡢξ礽ΥץȤ˥եХåեȤ뤳Ȥ̣롣
+    @li $LANGUAGE が @c Mt ならば、plist 
+    のキーはフォントが指定されている言語名のシンボルであり、値は
+    NULL である。キーは @c Mt
+    であることもあり、その場合そのスクリプトにフォールバックフォントがあることを意味する。
 
-    @li $LANGUAGE ̾ΥܥʤСplist ϻΥץȤȸФ
-    @c FONT-GROUP Ǥ롣@c FONT-GROUP Ȥϡ FLT
-    (FontLayoutTable) ̾ΥܥǤꡢͤ #MFont 
-    ؤΥݥ󥿤Ǥ褦 plist Ǥ롣եȤ FLT 
-    бդƤʤˤϡ @c Mt ˤʤ롣
+    @li $LANGUAGE が言語名のシンボルならば、plist は指定のスクリプトと言語に対する
+    @c FONT-GROUP である。@c FONT-GROUP とは、キーが FLT
+    (FontLayoutTable) 名のシンボルであり、値が #MFont 
+    へのポインタであるような plist である。ただしフォントに FLT 
+    が対応付けられていない時には、キーは @c Mt になる。
 
-    @li $LANGUAGE  @c Mnil ʤСplist ϤΥץѤΥեХå
-    @c FONT-GROUP Ǥ롣
+    @li $LANGUAGE が @c Mnil ならば、plist はそのスクリプト用のフォールバック
+    @c FONT-GROUP である。
 
-    $SCRIPT  @c Mnil ʤС֤ plist ϰʲΤ褦ޤ롣
+    $SCRIPT が @c Mnil ならば、返す plist は以下のように定まる。
 
-    @li $CHARSET  @c Mt ʤСplist 
-    ΥϥեȤꤵƤʸå̾ΥܥǤꡢͤ
-    NULL Ǥ롣
+    @li $CHARSET が @c Mt ならば、plist 
+    のキーはフォントが指定されている文字セット名のシンボルであり、値は
+    NULL である。
 
-    @li $CHARSET ʸå̾ΥܥʤСplist ϤʸåѤ 
-    @c FONT-GROUP Ǥ롣
+    @li $CHARSET が文字セット名のシンボルならば、plist はその文字セット用の 
+    @c FONT-GROUP である。
 
-    @li $CHARSET  @c Mnil ʤСplist ϥեХå @c FONT-GROUP Ǥ롣
+    @li $CHARSET が @c Mnil ならば、plist はフォールバック @c FONT-GROUP である。
 
     @return
-    δؿϥեȥåȤƤɽ plist ֤
-    plist  m17n_object_unref () ǲ٤Ǥ롣  */
+    この関数はフォントセットの内容を表す plist を返す。
+    plist は m17n_object_unref () で解放されるべきである。  */
 
 MPlist *
 mfontset_lookup (MFontset *fontset,
@@ -1448,20 +1450,22 @@ mfontset_lookup (MFontset *fontset,
 /***en
     @brief Dump a fontset.
 
-    The mdebug_dump_fontset () function prints fontset $FONTSET in a human readable
-    way to the stderr.  $INDENT specifies how many columns to indent
-    the lines but the first one.
+    The mdebug_dump_fontset () function prints fontset $FONTSET in a
+    human readable way to the stderr or to what specified by the
+    environment variable MDEBUG_OUTPUT_FILE.  $INDENT specifies how
+    many columns to indent the lines but the first one.
 
     @return
     This function returns $FONTSET.  */
 /***ja
-    @brief եȥåȤפ.
+    @brief フォントセットをダンプする.
 
-    ؿ mdebug_dump_face () ϥեȥå $FONTSET  stderr 
-    ˿ʹ֤˲ɤʷǰ롣 $INDENT ϣܰʹߤΥǥȤꤹ롣
+    関数 mdebug_dump_face () はフォントセット $FONTSET を標準エラー出力
+    もしくは環境変数 MDEBUG_DUMP_FONT で指定されたファイルに人間に可読
+    な形で出力する。 $INDENT は２行目以降のインデントを指定する。
 
     @return
-    δؿ $FONTSET ֤  */
+    この関数は $FONTSET を返す。  */
 
 MFontset *
 mdebug_dump_fontset (MFontset *fontset, int indent)
@@ -1472,48 +1476,50 @@ mdebug_dump_fontset (MFontset *fontset, int indent)
   memset (prefix, 32, indent);
   prefix[indent] = 0;
 
-  fprintf (stderr, "(fontset %s", fontset->name->name);
+  fprintf (mdebug__output, "(fontset %s", fontset->name->name);
   if (fontset->per_script)
     MPLIST_DO (plist, fontset->per_script)
       {
-	fprintf (stderr, "\n  %s(%s", prefix, MPLIST_KEY (plist)->name);
+	fprintf (mdebug__output, "\n  %s(%s", prefix, MPLIST_KEY (plist)->name);
 	MPLIST_DO (pl, MPLIST_PLIST (plist))
 	  {
-	    fprintf (stderr, "\n    %s(%s", prefix, MPLIST_KEY (pl)->name);
+	    fprintf (mdebug__output, "\n    %s(%s", prefix,
+		     MPLIST_KEY (pl)->name);
 	    MPLIST_DO (p, MPLIST_PLIST (pl))
 	      {
-		fprintf (stderr, "\n      %s(0x%X %s ", prefix,
+		fprintf (mdebug__output, "\n      %s(0x%X %s ", prefix,
 			 (unsigned) MPLIST_VAL (p),
 			 MPLIST_KEY (p)->name);
 		mdebug_dump_font (MPLIST_VAL (p));
-		fprintf (stderr, ")");
+		fprintf (mdebug__output, ")");
 	      }
-	    fprintf (stderr, ")");
+	    fprintf (mdebug__output, ")");
 	  }
-	fprintf (stderr, ")");
+	fprintf (mdebug__output, ")");
       }
   if (fontset->per_charset)
     MPLIST_DO (pl, fontset->per_charset)
       {
-	fprintf (stderr, "\n  %s(%s", prefix, MPLIST_KEY (pl)->name);
+	fprintf (mdebug__output, "\n  %s(%s", prefix, MPLIST_KEY (pl)->name);
 	MPLIST_DO (p, MPLIST_PLIST (pl))
 	  {
-	    fprintf (stderr, "\n    %s(%s ", prefix, MPLIST_KEY (p)->name);
+	    fprintf (mdebug__output, "\n    %s(%s ", prefix,
+		     MPLIST_KEY (p)->name);
 	    mdebug_dump_font (MPLIST_VAL (p));
-	    fprintf (stderr, ")");
+	    fprintf (mdebug__output, ")");
 	  }
-	fprintf (stderr, ")");
+	fprintf (mdebug__output, ")");
       }
 
   if (fontset->fallback)
     MPLIST_DO (p, fontset->fallback)
       {
-	fprintf (stderr, "\n  %s(%s ", prefix, MPLIST_KEY (p)->name);
+	fprintf (mdebug__output, "\n  %s(%s ", prefix, MPLIST_KEY (p)->name);
 	mdebug_dump_font (MPLIST_VAL (p));
-	fprintf (stderr, ")");
+	fprintf (mdebug__output, ")");
       }
 
-  fprintf (stderr, ")");
+  fprintf (mdebug__output, ")");
   return fontset;
 }
 
@@ -1521,6 +1527,6 @@ mdebug_dump_fontset (MFontset *fontset, int indent)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
