@@ -1,5 +1,5 @@
 /* internal.h -- common header file for the internal CORE and SHELL APIs.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #ifndef _M17N_INTERNAL_H_
 #define _M17N_INTERNAL_H_
@@ -299,23 +299,23 @@ typedef struct
 typedef struct
 {
   /**en Reference count of the object.  */
-  /**ja ֥Ȥλȿ.  */
+  /**ja オブジェクトの参照数.  */
   unsigned ref_count : 16;
 
   unsigned ref_count_extended : 1;
 
   /**en A flag bit used for various perpose.  */
-  /**ja ޤޤŪѤե饰ӥå.  */
+  /**ja さまざまな目的に用いられるフラグビット.  */
   unsigned flag : 15;
 
   union {
     /**en If <ref_count_extended> is zero, a function to free the
        object.  */
-    /**ja <ref_count_extended>  0 ʤХ֥Ȥؿ.  */
+    /**ja <ref_count_extended> が 0 ならばオブジェクトを解放する関数.  */
     void (*freer) (void *);
     /**en If <ref_count_extended> is nonzero, a pointer to the
        struct M17NObjectRecord.  */
-    /**ja <ref_count_extended>  0 Ǥʤй¤ M17NObjectRecord ؤΥݥ.  */
+    /**ja <ref_count_extended> が 0 でなければ構造体 M17NObjectRecord へのポインタ.  */
     M17NObjectRecord *record;
   } u;
 } M17NObject;
@@ -333,7 +333,7 @@ typedef struct
 
 /**en Increment the reference count of OBJECT if the count is not
    0.  */
-/**ja OBJECT λȿ 0 Ǥʤ 1 䤹.  */
+/**ja OBJECT の参照数が 0 でなければ 1 増やす.  */
 
 #define M17N_OBJECT_REF(object)				\
   do {							\
@@ -375,15 +375,19 @@ typedef struct
 
 /**en Decrement the reference count of OBJECT if the count is greater
       than 0.  In that case, if the count becomes 0, free OBJECT.  */
-/**ja OBJECT λȿ 0 礭 1 餹餷 0 ˤʤ
-      OBJECT .  */
+/**ja OBJECT の参照数が 0 より大きければ 1 減らす。減らして 0 になれば
+      OBJECT を解放する.  */
 
 #define M17N_OBJECT_UNREF(object)					\
   do {									\
     if (object)								\
       {									\
-	if (((M17NObject *) (object))->ref_count_extended)		\
-	  m17n_object_unref (object);					\
+	if (((M17NObject *) (object))->ref_count_extended		\
+	    || mdebug__flags[MDEBUG_FINI])				\
+	  {								\
+	    if (m17n_object_unref (object) == 0)			\
+	      (object) = NULL;						\
+	  }								\
 	else if (((M17NObject *) (object))->ref_count == 0)		\
 	  break;							\
 	else								\
@@ -452,27 +456,27 @@ struct MText
   unsigned coverage : 16;
 
   /**en Number of characters in the M-text */
-  /**ja M-text ʸ */
+  /**ja M-text 中の文字数 */
   int nchars;
 
   /**en Number of bytes used to represent the characters in the M-text. */
-  /**ja M-text ʸɽ魯ѤХȿ */
+  /**ja M-text 中の文字を表わすために用いられるバイト数 */
   int nbytes;
 
   /**en Character sequence of the M-text. */
-  /**ja M-text ʸ */
+  /**ja M-text 中の文字列 */
   unsigned char *data;
 
   /**en Number of bytes allocated for the @c data member. */
-  /**ja  @c data ˳Ƥ줿Хȿ */
+  /**ja メンバ @c data に割り当てられたバイト数 */
   int allocated;
 
   /**en Pointer to the property list of the M-text. */
-  /**ja M-text ΥץѥƥꥹȤؤΥݥ */
+  /**ja M-text のプロパティリストへのポインタ */
   struct MTextPlist *plist;
 
   /**en Caches of the character position and the corresponding byte position. */
-  /**ja ʸ֤бХȰ֤Υå */
+  /**ja 文字位置および対応するバイト位置のキャッシュ */
   int cache_char_pos, cache_byte_pos;
 };
 
@@ -676,6 +680,6 @@ extern void minput__fini ();
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
