@@ -1,5 +1,5 @@
 /* m17n-flt.c -- Font Layout Table sub-module.
-   Copyright (C) 2003, 2004, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nFLT
@@ -30,11 +30,11 @@
 
 /***ja
     @addtogroup m17nFLT
-    @brief ɥƥΤ FLT ݡ.
+    @brief ウィンドウシステムのための FLT サポート.
 
-    ΥǤϡFLT (Font Layout Table)
-    Ѥʸ쥤ȵǽ˴ؤ m17n FLT API 롣
-    FLT η @ref mdbFLT ˵ҤƤ롣  */
+    このセクションでは、FLT (Font Layout Table)
+    を用いた文字レイアウト機能に関する m17n FLT API を定義する。
+    FLT の形式は @ref mdbFLT に記述されている。  */
 
 /*=*/
 
@@ -742,14 +742,31 @@ otf_store_features (char *p, char *end, unsigned *buf)
   buf[i] = 0;
 }
 
+/* SYMBOL's name	features[0]		for checking	for applying
+			       features[1]      GSUB     GPOS	GSUB    GPOS
+   -------------	------------------	-------------	------------
+   SCRIPT		[-1,0]	    [-1,0]	   any | any	   all  all
+   SCRIPT=		NULL	    [-1,0]	  none & 1	  none  all
+   SCRIPT+		[-1,0]	      NULL	     1 & none	   all  none
+   SCRIPT=+		NULL	      NULL	  none & none	  none  none
+   SCRIPT=F1		[F1,0]	    [-1,0]	    F1 & 1	    F1  all
+   SCRIPT+F1		[-1][0]	    [F1,0]	     1 & F1	  none  F1
+   SCRIPT=F1+		[F1,0]	      NULL	    F1 & none	    F1  none
+   SCRIPT=~F2		[-1,F2,0]   [-1,0]	   ~F2 & 1	all~F2  all
+   SCRIPT=F1,~F2	[F1,-1,F2,0][-1,0]	F1&~F2 & 1	F1 (*1) all
+
+   (*1) Invalid specification
+ */
+
 static int
 parse_otf_command (MSymbol symbol, MFLTOtfSpec *spec)
 {
   char *str = MSYMBOL_NAME (symbol);
   char *end = str + MSYMBOL_NAMELEN (symbol);
   unsigned int script, langsys;
-  char *gsub, *gpos;
-  int gsub_count = 0, gpos_count = 0;
+  char *features[3];
+  int feature_count[2];		/* [0]:GSUB, [1]:GPOS */
+  int i;
   char *p;
 
   memset (spec, 0, sizeof (MFLTOtfSpec));
@@ -765,64 +782,53 @@ parse_otf_command (MSymbol symbol, MFLTOtfSpec *spec)
 	/* This is a spec to reset category codes.  */
 	return 0;
     }
-  script = gen_otf_tag (str, 8);
+  spec->script = gen_otf_tag (str, 8);
   str += 4;
   if (*str == '/')
     {
-      langsys = gen_otf_tag (str, 8);
+      spec->langsys = gen_otf_tag (str, 8);
       str += 4;
     }
   else
-    langsys = 0;
-  gsub = str;
+    spec->langsys = 0;
+  features[0] = str;
   if (*str != '=')
     /* Apply all GSUB features.  */
-      gsub_count = 1;
+      feature_count[0] = -1;
   else
     {
       p = str + 1;
-      str = otf_count_features (p, end, '+', &gsub_count);
+      str = otf_count_features (p, end, '+', feature_count);
       if (! str)
 	MERROR (MERROR_FLT, -1);
     }
-  gpos = str;
+  features[1] = str;
   if (*str != '+')
     /* Apply all GPOS features.  */
-    gpos_count = 1;
+    feature_count[1] = -1;
   else
     {
       p = str + 1;
-      str = otf_count_features (p, end, '\0', &gpos_count);
+      str = otf_count_features (p, end, '\0', feature_count + 1);
       if (! str)
 	MERROR (MERROR_FLT, -1);
     }
-
-  spec->script = script;
-  spec->langsys = langsys;
-  if (gsub_count > 0)
-    {
-      spec->features[0] = malloc (sizeof (int) * (gsub_count + 1));
-      if (! spec->features[0])
-	return -2;
-      if (*gsub == '=')
-	otf_store_features (gsub + 1, gpos, spec->features[0]);
-      else
-	spec->features[0][0] = 0xFFFFFFFF, spec->features[0][1] = 0;
-    }
-  if (gpos_count > 0)
-    {
-      spec->features[1] = malloc (sizeof (int) * (gpos_count + 1));
-      if (! spec->features[1])
-	{
-	  if (spec->features[0])
-	    free (spec->features[0]);
+  features[2] = str;
+  for (i = 0; i < 2; i++)
+    if (feature_count[i])
+      {
+	spec->features[i] = malloc (sizeof (int)
+				    * (feature_count[i] < 0 ? 2
+				       : feature_count[i] + 1));
+	if (! spec->features[i])
 	  return -2;
-	}
-      if (*gpos == '+')
-	otf_store_features (gpos + 1, str, spec->features[1]);
-      else
-	spec->features[1][0] = 0xFFFFFFFF, spec->features[1][1] = 0;
-    }
+	if (feature_count[i] > 0)
+	  otf_store_features (features[i] + 1, features[i + 1],
+			      spec->features[i]);
+	else
+	  spec->features[i][0] = 0xFFFFFFFF, spec->features[i][1] = 0;
+      }
+
   return 0;
 }
 
@@ -1882,13 +1888,14 @@ decode_packed_otf_tag (FontLayoutContext *ctx, MFLTGlyphString *gstring,
 	  SET_CATEGORY_CODE (g, 0);
 	  continue;
 	}
+      enc = '\0';
       if (tag & 0xFFFFF80)
 	{
 	  int i;
 
 	  /* Clear the feature tag code.  */
 	  g->internal &= ~0xFFFFFFF;
-	  for (i = 0, enc = '\0'; i < category->feature_table.size; i++)
+	  for (i = 0; i < category->feature_table.size; i++)
 	    if (category->feature_table.tag[i] == tag)
 	      {
 		enc = category->feature_table.code[i];
@@ -1897,10 +1904,9 @@ decode_packed_otf_tag (FontLayoutContext *ctx, MFLTGlyphString *gstring,
 		break;
 	      }
 	}
-      else
-	enc = '\0';
       if (! enc)
-	enc = g->c > 0 ? (int) mchartable_lookup (category->table, g->c) : 1;
+	enc = (g->c > 0 ? (int) mchartable_lookup (category->table, g->c)
+	       : g->c == 0 ? 1 : ' ');
       SET_CATEGORY_CODE (g, enc);
     }
 }
@@ -2018,7 +2024,6 @@ try_otf (int depth, MFLTOtfSpec *otf_spec, int from, int to,
 	 FontLayoutContext *ctx)
 {
   MFLTFont *font = ctx->font;
-  int from_idx = ctx->out->used;
 
   if (MDEBUG_FLAG () > 2)
     MDEBUG_PRINT3 ("\n [FLT] %*s%s", depth, "", MSYMBOL_NAME (otf_spec->sym));
@@ -2054,9 +2059,6 @@ try_otf (int depth, MFLTOtfSpec *otf_spec, int from, int to,
   font->get_glyph_id (font, ctx->in, from, to);
   if (mflt_try_otf)
     {
-      int out_len;
-      int i;
-
       to = mflt_try_otf (font, otf_spec, ctx->in, from, to);
       if (to < 0)
 	return from;
@@ -2237,12 +2239,14 @@ run_command (int depth, int id, int from, int to, FontLayoutContext *ctx)
       {
 	int i;
 
+	if (MDEBUG_FLAG () > 2)
+	  MDEBUG_PRINT2 ("\n [FLT] %*s|", depth, "");
 	i = from < to ? from : from - 1;
 	GDUP (ctx, i);
 	g = GREF (ctx->out, ctx->out->used - 1);
 	g->c = -1, g->code = 0;
 	g->xadv = g->yadv = 0;
-	SET_ENCODED (g, 0);
+	SET_ENCODED (g, 1);
 	SET_MEASURED (g, 0);
 	SET_CATEGORY_CODE (g, ' ');
 	return from;
@@ -2283,7 +2287,7 @@ run_stages (MFLTGlyphString *gstring, int from, int to,
 
   from_pos = GREF (ctx->in, from)->from;
   to_pos = GREF (ctx->in, to - 1)->to;
-  len = to_pos - from_pos;
+  len = to_pos - from_pos + 1;
 
   buf = *(ctx->in);
   buf.glyphs = NULL;
@@ -2381,9 +2385,6 @@ run_stages (MFLTGlyphString *gstring, int from, int to,
 
   if (ctx->out->used > 0)
     {
-      int *g_indices;
-      int x_ppem = ctx->font->x_ppem << 6, y_ppem = ctx->font->y_ppem << 6;
-
       /* Remove separator glyphs.  */
       for (i = 0; i < ctx->out->used;)
 	{
@@ -2393,6 +2394,11 @@ run_stages (MFLTGlyphString *gstring, int from, int to,
 	  else
 	    i++;
 	}
+    }
+  if (ctx->out->used > 0)
+    {
+      int *g_indices;
+      int x_ppem = ctx->font->x_ppem << 6, y_ppem = ctx->font->y_ppem << 6;
 
       /* Get actual glyph IDs of glyphs.  */
       ctx->font->get_glyph_id (ctx->font, ctx->out, 0, ctx->out->used);
@@ -2421,6 +2427,8 @@ run_stages (MFLTGlyphString *gstring, int from, int to,
 		int this_from;
 
 		for (i++; i < len && g_indices[i] < 0; i++);
+		if (! (i < len))
+		  break;
 		j = g_indices[i];
 		g = GREF (ctx->out, j);
 		this_from = g->from;
@@ -2676,7 +2684,7 @@ m17n_init_flt (void)
   mflt_font_id = NULL;
   mflt_try_otf = NULL;
 
-  MDEBUG_PRINT_TIME ("INIT", (stderr, " to initialize the flt modules."));
+  MDEBUG_PRINT_TIME ("INIT", (mdebug__output, " to initialize the flt modules."));
   MDEBUG_POP_TIME ();
 }
 
@@ -2691,7 +2699,7 @@ m17n_fini_flt (void)
 
   MDEBUG_PUSH_TIME ();
   free_flt_list ();
-  MDEBUG_PRINT_TIME ("FINI", (stderr, " to finalize the flt modules."));
+  MDEBUG_PRINT_TIME ("FINI", (mdebug__output, " to finalize the flt modules."));
   MDEBUG_POP_TIME ();
   m17n_fini_core ();
 }
@@ -2714,13 +2722,13 @@ m17n_fini_flt (void)
     to the found FLT object.  Otherwise, it returns @c NULL.  */
 
 /***ja
-    @brief ꤵ줿̾ FLT ֥Ȥ֤.
+    @brief 指定された名前を持つ FLT オブジェクトを返す.
 
-    ؿ mflt_get () ϡ$NAME Ȥ̾ FLT ֥Ȥ֤
+    関数 mflt_get () は、$NAME という名前を持つ FLT オブジェクトを返す。
 
     @return
-    ⤷Сmflt_get () ϸĤä FLT
-    ֥ȤؤΥݥ󥿤֤Ԥ @c NULL ֤  */
+    もし成功すれば、mflt_get () は見つかった FLT
+    オブジェクトへのポインタを返す。失敗した場合は @c NULL を返す。  */
 
 MFLT *
 mflt_get (MSymbol name)
@@ -2755,14 +2763,14 @@ mflt_get (MSymbol name)
     to the found FLT object.  Otherwise, it returns @c NULL.  */
 
 /***ja
-    @brief ꤵ줿ʸȥեȤ˹ä FLT õ.
+    @brief 指定された文字とフォントに合った FLT を探す.
 
-    ؿ mflt_find () ϡʸ $C ե $FONT
-    ǥ쥤Ȥ뤿˺ǤŬڤ FLT ֤
+    関数 mflt_find () は、文字 $C をフォント $FONT
+    でレイアウトするために最も適切な FLT を返す。
 
     @return
-    ⤷Сmflt_find () ϸĤä FLT
-    ֥ȤؤΥݥ󥿤֤Ԥ @c NULL ֤  */
+    もし成功すれば、mflt_find () は見つかった FLT
+    オブジェクトへのポインタを返す。失敗した場合は @c NULL を返す。  */
 
 MFLT *
 mflt_find (int c, MFLTFont *font)
@@ -2848,9 +2856,9 @@ mflt_find (int c, MFLTFont *font)
     The mflt_name () function returns the name of $FLT.  */
 
 /***ja
-    @brief FLT ֤̾.
+    @brief FLT の名前を返す.
 
-    ؿ mflt_name ()  $FLT ֤̾  */
+    関数 mflt_name () は $FLT の名前を返す。  */
 
 const char *
 mflt_name (MFLT *flt)
@@ -2866,10 +2874,10 @@ mflt_name (MFLT *flt)
     nonzero values for characters supported by $FLT.  */
 
 /***ja
-    @brief FLT ϰϤ֤.
+    @brief FLT の範囲を返す.
 
-    ؿ mflt_coverage () ϡ$FLT ݡȤʸФ
-    0 Ǥʤͤޤʸơ֥֤  */
+    関数 mflt_coverage () は、$FLT がサポートする文字に対して
+    0 でない値を含む文字テーブルを返す。  */
 
 MCharTable *
 mflt_coverage (MFLT *flt)
@@ -2898,24 +2906,24 @@ mflt_coverage (MFLT *flt)
     Some other error occurred.  */
 
 /***ja
-    @brief FLT Ȥäʸ쥤Ȥ.
+    @brief FLT を使って文字をレイアウトする.
 
-    ؿ mflt_run () ϡ$GSTRING  $FROM  $TO ľޤǤʸ
-    $FONT Ѥƥ쥤Ȥ롣⤷ $FLT
-    ǤʤСͤ򤹤٤ƤʸФѤ롣
-    ǤʤŬڤ FLT ưŪ򤹤롣
+    関数 mflt_run () は、$GSTRING 中の $FROM から $TO 直前までの文字を
+    $FONT を用いてレイアウトする。もし $FLT
+    がゼロでなければ、その値をすべての文字に対して用いる。
+    そうでなければ適切な FLT を自動的に選択する。
 
     @retval >=0
-    ¹򼨤֤ͤϡ$GSTRING->glyphs ǰ $TO
-    ˤäƼƤդؤΥǥǤ롣
+    実行成功を示す。返される値は、$GSTRING->glyphs 中で以前 $TO
+    によって示されていたグリフへのインデクスである。
 
     @retval -2
-    ̤Ǽˤ $GSTRING->glyphs û뤳Ȥ򼨤
-    ƤӽФ¦ϡĹ $GSTRING->glyphs
-    Ѥƺ٤δؿƤ֤ȤǤ롣
+    結果を格納するには $GSTRING->glyphs が短すぎることを示す。
+    呼び出し側は、より長い $GSTRING->glyphs
+    を用いて再度この関数を呼ぶことができる。
 
     @retval -1
-    ¾Υ顼Ȥ򼨤  */
+    その他のエラーが起きたことを示す。  */
 
 int
 mflt_run (MFLTGlyphString *gstring, int from, int to,
@@ -3057,14 +3065,24 @@ mflt_run (MFLTGlyphString *gstring, int from, int to,
 	{
 	  MDEBUG_PRINT ("\n [FLT]   (RESULT");
 	  if (MDEBUG_FLAG () > 1)
-	    for (i = 0; this_from < this_to; this_from++, i++)
-	      {
-		if (i > 0 && i % 4 == 0)
-		  MDEBUG_PRINT ("\n [FLT]          ");
-		g = GREF (gstring, this_from);
-		MDEBUG_PRINT4 (" (%04X %d %d %d)",
-			       g->code, g->xadv, g->xoff, g->yoff);
-	      }
+	    {
+	      int idx = -1;
+	      for (i = 0; this_from < this_to; i++, this_from++)
+		{
+		  g = GREF (gstring, this_from);
+		  if (g->from != idx)
+		    {
+		      if (i > 0)
+			MDEBUG_PRINT2 ("\n [FLT]           %02d-%02d",
+				       g->from, g->to);
+		      else
+			MDEBUG_PRINT2 (" %02d-%02d", g->from, g->to);
+		      idx = g->from;
+		    }
+		  MDEBUG_PRINT4 (" (%04X %d %d %d)",
+				 g->code, g->xadv, g->xoff, g->yoff);
+		}
+	    }
 	  else
 	    for (; this_from < this_to; this_from++)
 	      MDEBUG_PRINT1 (" %04X", GREF (gstring, this_from)->code);
@@ -3093,6 +3111,13 @@ mflt_run (MFLTGlyphString *gstring, int from, int to,
   return to;
 }
 
+/***en
+    @brief Flag to control several new OTF handling commands.
+
+    If the variable mflt_enable_new_feature is nonzero, the function
+    #mflt_run () can drive a Font Layout Table that contains the new
+    OTF-related commands ":otf?" and/or OTF feature specification in a
+    category table.  */
 int mflt_enable_new_feature;
 
 int (*mflt_iterate_otf_feature) (struct _MFLTFont *font,
@@ -3117,7 +3142,7 @@ dump_flt_cmd (FontLayoutStage *stage, int id, int indent)
   prefix[indent] = 0;
 
   if (id >= 0)
-    fprintf (stderr, "0x%02X", id);
+    fprintf (mdebug__output, "0x%02X", id);
   else if (id <= CMD_ID_OFFSET_INDEX)
     {
       int idx = CMD_ID_TO_INDEX (id);
@@ -3128,57 +3153,58 @@ dump_flt_cmd (FontLayoutStage *stage, int id, int indent)
 	  FontLayoutCmdRule *rule = &cmd->body.rule;
 	  int i;
 
-	  fprintf (stderr, "(rule ");
+	  fprintf (mdebug__output, "(rule ");
 	  if (rule->src_type == SRC_REGEX)
-	    fprintf (stderr, "\"%s\"", rule->src.re.pattern);
+	    fprintf (mdebug__output, "\"%s\"", rule->src.re.pattern);
 	  else if (rule->src_type == SRC_INDEX)
-	    fprintf (stderr, "%d", rule->src.match_idx);
+	    fprintf (mdebug__output, "%d", rule->src.match_idx);
 	  else if (rule->src_type == SRC_SEQ)
-	    fprintf (stderr, "(seq)");
+	    fprintf (mdebug__output, "(seq)");
 	  else if (rule->src_type == SRC_RANGE)
-	    fprintf (stderr, "(range)");
+	    fprintf (mdebug__output, "(range)");
 	  else
-	    fprintf (stderr, "(invalid src)");
+	    fprintf (mdebug__output, "(invalid src)");
 
 	  for (i = 0; i < rule->n_cmds; i++)
 	    {
-	      fprintf (stderr, "\n%s  ", prefix);
+	      fprintf (mdebug__output, "\n%s  ", prefix);
 	      dump_flt_cmd (stage, rule->cmd_ids[i], indent + 2);
 	    }
-	  fprintf (stderr, ")");
+	  fprintf (mdebug__output, ")");
 	}
       else if (cmd->type == FontLayoutCmdTypeCond)
 	{
 	  FontLayoutCmdCond *cond = &cmd->body.cond;
 	  int i;
 
-	  fprintf (stderr, "(cond");
+	  fprintf (mdebug__output, "(cond");
 	  for (i = 0; i < cond->n_cmds; i++)
 	    {
-	      fprintf (stderr, "\n%s  ", prefix);
+	      fprintf (mdebug__output, "\n%s  ", prefix);
 	      dump_flt_cmd (stage, cond->cmd_ids[i], indent + 2);
 	    }
-	  fprintf (stderr, ")");
+	  fprintf (mdebug__output, ")");
 	}
       else if (cmd->type == FontLayoutCmdTypeOTF)
 	{
-	  fprintf (stderr, "(otf)");
+	  fprintf (mdebug__output, "(otf)");
 	}
       else
-	fprintf (stderr, "(error-command)");
+	fprintf (mdebug__output, "(error-command)");
     }
   else if (id <= CMD_ID_OFFSET_COMBINING)
-    fprintf (stderr, "cominging-code");
+    fprintf (mdebug__output, "cominging-code");
   else
-    fprintf (stderr, "(predefiend %d)", id);
+    fprintf (mdebug__output, "(predefiend %d)", id);
 }
 
 /***en
     @brief Dump a Font Layout Table.
 
     The mdebug_dump_flt () function prints the Font Layout Table $FLT
-    in a human readable way to the stderr.  $INDENT specifies how many
-    columns to indent the lines but the first one.
+    in a human readable way to the stderr or to what specified by the
+    environment variable MDEBUG_OUTPUT_FILE.  $INDENT specifies how
+    many columns to indent the lines but the first one.
 
     @return
     This function returns $FLT.  */
@@ -3192,44 +3218,51 @@ mdebug_dump_flt (MFLT *flt, int indent)
 
   memset (prefix, 32, indent);
   prefix[indent] = 0;
-  fprintf (stderr, "(flt");
+  fprintf (mdebug__output, "(flt");
   MPLIST_DO (plist, flt->stages)
     {
       FontLayoutStage *stage = (FontLayoutStage *) MPLIST_VAL (plist);
       int i;
 
-      fprintf (stderr, "\n%s  (stage %d", prefix, stage_idx);
+      fprintf (mdebug__output, "\n%s  (stage %d", prefix, stage_idx);
       for (i = 0; i < stage->used; i++)
 	{
-	  fprintf (stderr, "\n%s    ", prefix);
+	  fprintf (mdebug__output, "\n%s    ", prefix);
 	  dump_flt_cmd (stage, INDEX_TO_CMD_ID (i), indent + 4);
 	}
-      fprintf (stderr, ")");
+      fprintf (mdebug__output, ")");
       stage_idx++;
     }
-  fprintf (stderr, ")");
+  fprintf (mdebug__output, ")");
   return flt;
 }
 
+/***en
+    @brief Dump an MFLTGlyphString.
+
+    The mflt_dump_gstring () function prints the glyph sequence
+    $GSTRING in a human readable way to the stderr or to what
+    specified by the environment variable MDEBUG_OUTPUT_FILE.  */
+
 void
 mflt_dump_gstring (MFLTGlyphString *gstring)
 {
   int i;
 
-  fprintf (stderr, "(flt-gstring");
+  fprintf (mdebug__output, "(flt-gstring");
   for (i = 0; i < gstring->used; i++)
     {
       MFLTGlyph *g = GREF (gstring, i);
-      fprintf (stderr, "\n  (%02d pos:%d-%d c:%04X code:%04X cat:%c)",
+      fprintf (mdebug__output, "\n  (%02d pos:%d-%d c:%04X code:%04X cat:%c)",
 	       i, g->from, g->to, g->c, g->code, GET_CATEGORY_CODE (g));
     }
-  fprintf (stderr, ")\n");
+  fprintf (mdebug__output, ")\n");
 }
 
 /*** @} */
 
 /*
  Local Variables:
- coding: euc-japan
+ coding: utf-8
  End:
 */
