@@ -1,5 +1,5 @@
 /* mtext.c -- M-text module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nMtext
@@ -49,30 +49,30 @@
 /***ja
     @addtogroup m17nMtext
 
-    @brief M-text ֥ȤȤ˴ؤ API.
+    @brief M-text オブジェクトとそれに関する API.
 
-    m17n 饤֥ϡ C-string<tt>char *</tt>  <tt>unsigned
-    char *</tt>ˤǤϤʤ @e M-text ȸƤ֥֥ȤǥƥȤɽ롣
-    M-text Ĺ 0 ʾʸǤꡢʸʤȤ 
-    C-stringե롢ʸˤǤ롣
+    m17n ライブラリは、 C-string（<tt>char *</tt> や <tt>unsigned
+    char *</tt>）ではなく @e M-text と呼ぶオブジェクトでテキストを表現する。
+    M-text は長さ 0 以上の文字列であり、種々の文字ソース（たとえば 
+    C-string、ファイル、文字コード等）から作成できる。
 
-    M-text ˤϡC-string ˤʤʲħ롣     
+    M-text には、C-string にない以下の特徴がある。     
 
-    @li M-text ¿μʸƱˡߤơƱ˰ȤǤ롣
-    Unicode ƤʸϤ󡢤¿ʸޤǤⰷȤǤ롣
-    ¿ƥȤ򰷤ǤɬܤεǽǤ롣
+    @li M-text は非常に多くの種類の文字を、同時に、混在させて、同等に扱うことができる。
+    Unicode の全ての文字はもちろん、より多くの文字までも扱うことができる。
+    これは多言語テキストを扱う上では必須の機能である。
 
-    @li M-text γʸϡ@e ƥȥץѥƥ 
-    ȸƤФץѥƥ
-    ƥȥץѥƥˤäơƥȤγ̤˴ؤ͡ʾ
-    M-text ݻ뤳Ȥǽˤʤ롣
-    Τᡢξ򥢥ץꥱץŪ˰Ȥǽˤʤ롣
-    ޤM-text 
-    Τ˭٤ʾĤᡢץꥱץγƴؿǲ뤳ȤǤ롣
+    @li M-text 内の各文字は、@e テキストプロパティ 
+    と呼ばれるプロパティを持ち、
+    テキストプロパティによって、テキストの各部位に関する様々な情報を
+    M-text 内に保持することが可能になる。
+    そのため、それらの情報をアプリケーションプログラム内で統一的に扱うことが可能になる。
+    また、M-text 
+    自体が豊富な情報を持つため、アプリケーションプログラム中の各関数を簡素化することができる。
 
-    m17n 饤֥ϡ C-string 
-    뤿󶡤δؿƱΤΤ M-text 
-    뤿˥ݡȤƤ롣  */
+    さらにm17n ライブラリは、 C-string 
+    を操作するために提供される種々の関数と同等のものを M-text 
+    を操作するためにサポートしている。  */
 
 /*=*/
 
@@ -283,11 +283,13 @@ insert (MText *mt1, int pos, MText *mt2, int from, int to)
       if (total_bytes + unit_bytes > mt1->allocated)
 	{
 	  mt1->allocated = total_bytes + unit_bytes;
-	  MTABLE_REALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
+	  if (mt1->data)
+	    MTABLE_REALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
+	  else
+	    MTABLE_CALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
 	}
-      if (pos < mt1->nchars)
-	memmove (mt1->data + pos_byte + new_bytes, mt1->data + pos_byte,
-		 (mt1->nbytes - pos_unit + 1) * unit_bytes);
+      memmove (mt1->data + pos_byte + new_bytes, mt1->data + pos_byte,
+	       (mt1->nbytes - pos_unit + 1) * unit_bytes);
       memcpy (mt1->data + pos_byte, mt2->data + from_unit * unit_bytes,
 	      new_bytes);
     }
@@ -1587,7 +1589,7 @@ const int MTEXT_FORMAT_UTF_32 = MTEXT_FORMAT_UTF_32LE;
 /*=*/
 
 /***en The symbol whose name is "language".  */
-/***ja "language" Ȥ̾ĥܥ.  */
+/***ja "language" という名前を持つシンボル.  */
 MSymbol Mlanguage;
 
 /*=*/
@@ -1601,11 +1603,11 @@ MSymbol Mlanguage;
     function.  */
 
 /***ja
-    @brief M-textƤ.
+    @brief 新しいM-textを割り当てる.
 
-    ؿ mtext () ϡĹ 0 ο M-text 
-    ơؤΥݥ󥿤֤Ƥ줿 M-text ϡؿ
-    m17n_object_unref () ˤäƥ桼Ū˹Ԥʤʤ¤ꡢʤ
+    関数 mtext () は、長さ 0 の新しい M-text 
+    を割り当て、それへのポインタを返す。割り当てられた M-text は、関数
+    m17n_object_unref () によってユーザが明示的に行なわない限り、解放されない。
 
     @latexonly \IPAlabel{mtext} @endlatexonly  */
 
@@ -1656,33 +1658,33 @@ mtext ()
     pointer to the allocated M-text.  Otherwise it returns @c NULL and
     assigns an error code to the external variable #merror_code.  */
 /***ja
-    @brief Υǡ򸵤˿ M-text Ƥ.
+    @brief 指定のデータを元に新しい M-text を割り当てる.
 
-    ؿ mtext_from_data () ϡǿ $NITEMS  $DATA 
-    ǻꤵ줿ʸĿ M-text Ƥ롣$FORMAT  $DATA
-    ΥեޥåȤ򼨤
+    関数 mtext_from_data () は、要素数 $NITEMS の配列 $DATA 
+    で指定された文字列を持つ新しい M-text を割り当てる。$FORMAT は $DATA
+    のフォーマットを示す。
 
-    $FORMAT  #MTEXT_FORMAT_US_ASCII  #MTEXT_FORMAT_UTF_8 ʤС
-    $DATA Ƥ @c unsigned @c char Ǥꡢ$NITEMS 
-    ϥХñ̤ɽƤ롣
+    $FORMAT が #MTEXT_FORMAT_US_ASCII か #MTEXT_FORMAT_UTF_8 ならば、
+    $DATA の内容は @c unsigned @c char 型であり、$NITEMS 
+    はバイト単位で表されている。
 
-    $FORMAT  #MTEXT_FORMAT_UTF_16LE  #MTEXT_FORMAT_UTF_16BE ʤС
-    $DATA Ƥ @c unsigned @c short Ǥꡢ$NITEMS  unsigned
-    short ñ̤Ǥ롣
+    $FORMAT が #MTEXT_FORMAT_UTF_16LE か #MTEXT_FORMAT_UTF_16BE ならば、
+    $DATA の内容は @c unsigned @c short 型であり、$NITEMS は unsigned
+    short 単位である。
 
-    $FORMAT  #MTEXT_FORMAT_UTF_32LE  #MTEXT_FORMAT_UTF_32BE ʤС
-    $DATA Ƥ @c unsigned Ǥꡢ$NITEMS  unsigned ñ̤Ǥ롣
+    $FORMAT が #MTEXT_FORMAT_UTF_32LE か #MTEXT_FORMAT_UTF_32BE ならば、
+    $DATA の内容は @c unsigned 型であり、$NITEMS は unsigned 単位である。
 
-    Ƥ줿 M-text ʸѹǤʤ$DATA Ƥ 
-    M-text ͭʴ֤ѹƤϤʤʤ
+    割り当てられた M-text の文字列は変更できない。$DATA の内容は 
+    M-text が有効な間は変更してはならない。
 
-    Ƥ줿 M-text ϡؿ m17n_object_unref () 
-    ˤäƥ桼Ū˹Ԥʤʤ¤ꡢʤξǤ $DATA ϲʤ
+    割り当てられた M-text は、関数 m17n_object_unref () 
+    によってユーザが明示的に行なわない限り、解放されない。その場合でも $DATA は解放されない。
 
     @return 
-    Сmtext_from_data () ϳƤ줿M-text 
-    ؤΥݥ󥿤֤Ǥʤ @c NULL ֤ѿ #merror_code 
-    ˥顼ɤꤹ롣  */
+    処理が成功すれば、mtext_from_data () は割り当てられたM-text 
+    へのポインタを返す。そうでなければ @c NULL を返し外部変数 #merror_code 
+    にエラーコードを設定する。  */
 
 /***
     @errors
@@ -1717,7 +1719,7 @@ mtext_from_data (const void *data, int nitems, enum MTextFormat format)
     character containing that unit.
 
     The character position and unit position of the return value are
-    stored in $POS_IDX and $UNIT_DIX respectively if they are not
+    stored in $POS_IDX and $UNIT_IDX respectively if they are not
     NULL.
 
     <ul>
@@ -1786,9 +1788,9 @@ mtext_data (MText *mt, enum MTextFormat *fmt, int *nunits,
     M-text $MT.  */
 
 /***ja
-    @brief M-text ʸο.
+    @brief M-text 中の文字の数.
 
-    ؿ mtext_len ()  M-text $MT ʸο֤
+    関数 mtext_len () は M-text $MT 中の文字の数を返す。
 
     @latexonly \IPAlabel{mtext_len} @endlatexonly  */
 
@@ -1808,11 +1810,11 @@ mtext_len (MText *mt)
     error code to the external variable #merror_code.  */
 
 /***ja
-    @brief M-text λꤵ줿֤ʸ֤.
+    @brief M-text 中の指定された位置の文字を返す.
 
-    ؿ mtext_ref_char () ϡM-text $MT ΰ $POS 
-    ʸ֤顼Ф줿 -1 ֤ѿ #merror_code
-    ˥顼ɤꤹ롣
+    関数 mtext_ref_char () は、M-text $MT の位置 $POS 
+    の文字を返す。エラーが検出された場合は -1 を返し、外部変数 #merror_code
+    にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_ref_char} @endlatexonly  */
 
@@ -1841,7 +1843,7 @@ mtext_ref_char (MText *mt, int pos)
       if (mt->format != MTEXT_FORMAT_UTF_16)
 	{
 	  p1[0] = SWAP_16 (*p);
-	  if (p1[0] >= 0xD800 || p1[0] < 0xDC00)
+	  if (p1[0] >= 0xD800 && p1[0] < 0xDC00)
 	    p1[1] = SWAP_16 (p[1]);
 	  p = p1;
 	}
@@ -1870,14 +1872,14 @@ mtext_ref_char (MText *mt, int pos)
     variable #merror_code.  */
 
 /***ja
-    @brief M-text ˰ʸꤹ.
+    @brief M-text に一文字を設定する.
 
-    ؿ mtext_set_char () ϡƥȥץѥƥ̵ʸ $C  
-    M-text $MT ΰ $POS ꤹ롣
+    関数 mtext_set_char () は、テキストプロパティ無しの文字 $C を 
+    M-text $MT の位置 $POS に設定する。
 
     @return
-     mtext_set_char ()  0 ֤Ԥ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣
+    処理に成功すれば mtext_set_char () は 0 を返す。失敗すれば -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_set_char} @endlatexonly  */
 
@@ -1975,14 +1977,14 @@ mtext_set_char (MText *mt, int pos, int c)
     $C is an invalid character, it returns @c NULL.  */
 
 /***ja
-    @brief M-text ˰ʸɲä.
+    @brief M-text に一文字追加する.
 
-    ؿ mtext_cat_char () ϡƥȥץѥƥ̵ʸ $C  
-    M-text $MT ɲä롣
+    関数 mtext_cat_char () は、テキストプロパティ無しの文字 $C を 
+    M-text $MT の末尾に追加する。
 
     @return
-    δؿѹ줿 M-text $MT ؤΥݥ󥿤֤$C 
-    ʸǤʤˤ @c NULL ֤  */
+    この関数は変更された M-text $MT へのポインタを返す。$C 
+    が正しい文字でない場合には @c NULL を返す。  */
 
 /***
     @seealso
@@ -2063,13 +2065,13 @@ mtext_cat_char (MText *mt, int c)
     This function returns a pointer to the created copy.  */
 
 /***ja
-    @brief M-text Υԡ.
+    @brief M-text のコピーを作る.
 
-    ؿ mtext_dup () ϡM-text $MT Υԡ롣$MT 
-    ΥƥȥץѥƥϤ٤ƷѾ롣
+    関数 mtext_dup () は、M-text $MT のコピーを作る。$MT 
+    のテキストプロパティはすべて継承される。
 
     @return
-    δؿϺ줿ԡؤΥݥ󥿤֤
+    この関数は作られたコピーへのポインタを返す。
 
      @latexonly \IPAlabel{mtext_dup} @endlatexonly  */
 
@@ -2096,13 +2098,13 @@ mtext_dup (MText *mt)
     This function returns a pointer to the resulting M-text $MT1.  */
 
 /***ja
-    @brief 2Ĥ M-textϢ뤹.
+    @brief 2個の M-textを連結する.
 
-    ؿ mtext_cat () ϡ M-text $MT2  M-text $MT1 
-    դä롣$MT2 ΥƥȥץѥƥϤ٤ƷѾ롣$MT2 ѹʤ
+    関数 mtext_cat () は、 M-text $MT2 を M-text $MT1 
+    の末尾に付け加える。$MT2 のテキストプロパティはすべて継承される。$MT2 は変更されない。
 
     @return
-    δؿѹ줿 M-text $MT1 ؤΥݥ󥿤֤
+    この関数は変更された M-text $MT1 へのポインタを返す。
 
     @latexonly \IPAlabel{mtext_cat} @endlatexonly  */
 
@@ -2138,16 +2140,16 @@ mtext_cat (MText *mt1, MText *mt2)
     #merror_code.  */
 
 /***ja
-    @brief M-text ΰ̤ M-text ղä.
+    @brief M-text の一部を別の M-text に付加する.
 
-    ؿ mtext_ncat () ϡM-text $MT2 ΤϤ $N ʸ M-text
-    $MT1 դä롣$MT2 ΥƥȥץѥƥϤ٤ƷѾ롣$MT2
-    Ĺ $N ʲʤС$MT2 Τ٤Ƥʸղä롣 $MT2 ѹʤ
+    関数 mtext_ncat () は、M-text $MT2 のはじめの $N 文字を M-text
+    $MT1 の末尾に付け加える。$MT2 のテキストプロパティはすべて継承される。$MT2
+    の長さが $N 以下ならば、$MT2 のすべての文字が付加される。 $MT2 は変更されない。
 
     @return
-    硢mtext_ncat () ѹ줿 M-text $MT1
-    ؤΥݥ󥿤֤顼Ф줿 @c NULL ֤ѿ
-    #merror_code ˥顼ɤꤹ롣
+    処理が成功した場合、mtext_ncat () は変更された M-text $MT1
+    へのポインタを返す。エラーが検出された場合は @c NULL を返し、外部変数
+    #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_ncat} @endlatexonly  */
 
@@ -2184,14 +2186,14 @@ mtext_ncat (MText *mt1, MText *mt2, int n)
     This function returns a pointer to the resulting M-text $MT1.  */
 
 /***ja
-    @brief M-text ̤ M-text ˥ԡ.
+    @brief M-text を別の M-text にコピーする.
 
-    ؿ mtext_cpy ()  M-text $MT2  M-text $MT1 ˾񤭥ԡ롣
-    $MT2 ΥƥȥץѥƥϤ٤ƷѾ롣$MT1 
-    Ĺɬפ˱ƿФ롣$MT2 ѹʤ
+    関数 mtext_cpy () は M-text $MT2 を M-text $MT1 に上書きコピーする。
+    $MT2 のテキストプロパティはすべて継承される。$MT1 
+    の長さは必要に応じて伸ばされる。$MT2 は変更されない。
 
     @return
-    δؿѹ줿 M-text $MT1 ؤΥݥ󥿤֤
+    この関数は変更された M-text $MT1 へのポインタを返す。
 
     @latexonly \IPAlabel{mtext_cpy} @endlatexonly  */
 
@@ -2227,17 +2229,17 @@ mtext_cpy (MText *mt1, MText *mt2)
     #merror_code.  */
 
 /***ja
-    @brief M-text ˴ޤޤǽβʸ򥳥ԡ.
+    @brief M-text に含まれる最初の何文字かをコピーする.
 
-    ؿ mtext_ncpy () ϡM-text $MT2 κǽ $N ʸ M-text $MT1 
-    ˾񤭥ԡ롣$MT2 ΥƥȥץѥƥϤ٤ƷѾ롣⤷ $MT2
-    Ĺ $N ⾮ $MT2 Τ٤Ƥʸ򥳥ԡ롣$MT1 
-    Ĺɬפ˱ƿФ롣$MT2 ѹʤ
+    関数 mtext_ncpy () は、M-text $MT2 の最初の $N 文字を M-text $MT1 
+    に上書きコピーする。$MT2 のテキストプロパティはすべて継承される。もし $MT2
+    の長さが $N よりも小さければ $MT2 のすべての文字をコピーする。$MT1 
+    の長さは必要に応じて伸ばされる。$MT2 は変更されない。
 
     @return 
-    硢mtext_ncpy () ѹ줿 M-text $MT1 
-    ؤΥݥ󥿤֤顼Ф줿 @c NULL ֤ѿ 
-    #merror_code ˥顼ɤꤹ롣
+    処理が成功した場合、mtext_ncpy () は変更された M-text $MT1 
+    へのポインタを返す。エラーが検出された場合は @c NULL を返し、外部変数 
+    #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_ncpy} @endlatexonly  */
 
@@ -2277,16 +2279,16 @@ mtext_ncpy (MText *mt1, MText *mt2, int n)
     #merror_code.  */
 
 /***ja
-    @brief ¸ M-text ΰ鿷 M-text Ĥ.
+    @brief 既存の M-text の一部から新しい M-text をつくる.
 
-    ؿ mtext_duplicate () ϡM-text $MT  $FROM $FROM Τޤˤ
-    $TO $TO ΤϴޤޤʤˤޤǤʬΥԡ롣ΤȤ $MT 
-    ΥƥȥץѥƥϤ٤ƷѾ롣$MT ΤΤѹʤ
+    関数 mtext_duplicate () は、M-text $MT の $FROM （$FROM 自体も含む）から
+    $TO （$TO 自体は含まない）までの部分のコピーを作る。このとき $MT 
+    のテキストプロパティはすべて継承される。$MT そのものは変更されない。
 
     @return
-    Сmtext_duplicate () Ϻ줿 M-text 
-    ؤΥݥ󥿤֤顼Ф줿 @c NULL ֤ѿ 
-    #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば、mtext_duplicate () は作られた M-text 
+    へのポインタを返す。エラーが検出された場合は @c NULL を返し、外部変数 
+    #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_duplicate} @endlatexonly  */
 
@@ -2326,19 +2328,19 @@ mtext_duplicate (MText *mt, int from, int to)
     an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief M-text ˻ϰϤʸ򥳥ԡ.
+    @brief M-text に指定範囲の文字をコピーする.
 
-    ؿ mtext_copy () ϡ M-text $MT2  $FROM $FROM Τޤˤ 
-    $TO $TO ΤϴޤޤʤˤޤǤϰϤΥƥȤ M-text $MT1 ΰ $POS
-    񤭥ԡ롣$MT2 ΥƥȥץѥƥϤ٤ƷѾ롣$MT1 
-    Ĺɬפ˱ƿФ롣$MT2 ѹʤ
+    関数 mtext_copy () は、 M-text $MT2 の $FROM （$FROM 自体も含む）から 
+    $TO （$TO 自体は含まない）までの範囲のテキストを M-text $MT1 の位置 $POS
+    から上書きコピーする。$MT2 のテキストプロパティはすべて継承される。$MT1 
+    の長さは必要に応じて伸ばされる。$MT2 は変更されない。
 
     @latexonly \IPAlabel{mtext_copy} @endlatexonly
 
     @return
-    硢mtext_copy () ѹ줿 $MT1 
-    ؤΥݥ󥿤֤Ǥʤ @c NULL ֤ѿ #merror_code 
-    ˥顼ɤꤹ롣  */
+    処理が成功した場合、mtext_copy () は変更された $MT1 
+    へのポインタを返す。そうでなければ @c NULL を返し、外部変数 #merror_code 
+    にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2374,15 +2376,15 @@ mtext_copy (MText *mt1, int pos, MText *mt2, int from, int to)
     variable #merror_code.  */
 
 /***ja
-    @brief ϰϤʸ˲Ū˼.
+    @brief 指定範囲の文字を破壊的に取り除く.
 
-    ؿ mtext_del () ϡM-text $MT  $FROM $FROM Τޤˤ
-    $TO $TO ΤϴޤޤʤˤޤǤʸ˲Ū˼Ū
-    $MT Ĺ ($TO @c - $FROM) ̤ळȤˤʤ롣
+    関数 mtext_del () は、M-text $MT の $FROM （$FROM 自体も含む）から
+    $TO （$TO 自体は含まない）までの文字を破壊的に取り除く。結果的に
+    $MT は長さが ($TO @c - $FROM) だけ縮むことになる。
 
     @return
-     mtext_del ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば mtext_del () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2442,15 +2444,15 @@ mtext_del (MText *mt, int from, int to)
     variable #merror_code.  */
 
 /***ja
-    @brief M-text ̤ M-text .
+    @brief M-text を別の M-text に挿入する.
 
-    ؿ mtext_ins ()  M-text $MT1  $POS ΰ֤̤ M-text $MT2 
-    롣η $MT1 Ĺ $MT2 Ĺʬ롣κݡ$MT2
-    ΥƥȥץѥƥϤ٤ƷѾ롣$MT2 ΤΤѹʤ
+    関数 mtext_ins () は M-text $MT1 の $POS の位置に別の M-text $MT2 
+    を挿入する。この結果 $MT1 の長さは $MT2 の長さ分だけ増える。挿入の際、$MT2
+    のテキストプロパティはすべて継承される。$MT2 そのものは変更されない。
 
     @return
-     mtext_ins ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば mtext_ins () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2488,17 +2490,17 @@ mtext_ins (MText *mt1, int pos, MText *mt2)
     external variable #merror_code.  */
 
 /***ja
-    @brief M-text ΰ̤ M-text .
+    @brief M-text の一部を別の M-text に挿入する.
 
-    ؿ mtext_insert ()  M-text $MT1  $POS ΰ֤ˡ̤ 
-    M-text $MT2  $FROM $FROM Τޤˤ $TO $TO Τϴޤ
-    ʤˤޤǤʸ롣Ū $MT1 Ĺ ($TO - $FROM) 
-    Ӥ롣κݡ $MT2 ΥƥȥץѥƥϤ٤ƷѾ
-    롣
+    関数 mtext_insert () は M-text $MT1 中の $POS の位置に、別の 
+    M-text $MT2 の $FROM （$FROM 自体も含む）から $TO （$TO 自体は含ま
+    ない）までの文字を挿入する。結果的に $MT1 は長さが ($TO - $FROM) 
+    だけ伸びる。挿入の際、 $MT2 中のテキストプロパティはすべて継承され
+    る。
 
     @return
-    Сmtext_insert ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば、mtext_insert () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2533,14 +2535,14 @@ mtext_insert (MText *mt1, int pos, MText *mt2, int from, int to)
     variable #merror_code.  */
 
 /***ja
-    @brief M-text ʸ.
+    @brief M-text に文字を挿入する.
 
-    ؿ mtext_ins_char ()  M-text $MT  $POS ΰ֤ʸ $C Υԡ $N
-    롣η $MT1 Ĺ $N 롣
+    関数 mtext_ins_char () は M-text $MT の $POS の位置に文字 $C のコピーを $N
+    個挿入する。この結果 $MT1 の長さは $N だけ増える。
 
     @return
-     mtext_ins_char ()  0 ֤Ǥʤ -1
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば mtext_ins_char () は 0 を返す。そうでなければ -1
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2641,17 +2643,17 @@ mtext_ins_char (MText *mt, int pos, int c, int n)
     external variable #merror_code.  */
 
 /***ja
-    @brief M-text ΰ̤ M-text ΰִ.
+    @brief M-text の一部を別の M-text の一部で置換する.
 
-    ؿ mtext_replace () ϡ M-text $MT1  $FROM1 $FROM1 Τ
-    ˤ $TO1 $TO1 ΤϴޤޤʤˤޤǤ M-text $MT2  
-    $FROM2 $FROM2 Τޤˤ $TO2 $TO2 Τϴޤޤʤˤ
-    롣줿ʬϡ֤Υƥȥץѥƥ
-    ٤ƤѾ롣
+    関数 mtext_replace () は、 M-text $MT1 の $FROM1 （$FROM1 自体も含
+    む）から $TO1 （$TO1 自体は含まない）までを、 M-text $MT2 の 
+    $FROM2 （$FROM2 自体も含む）から $TO2 （$TO2 自体は含まない）で置
+    き換える。新しく挿入された部分は、置き換える前のテキストプロパティ
+    すべてを継承する。
 
     @return 
-    С mtext_replace ()  0 ֤Ǥ
-     -1 ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば、 mtext_replace () は 0 を返す。そうでな
+    ければ -1 を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -2770,19 +2772,19 @@ mtext_replace (MText *mt1, int from1, int to1,
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief M-text ʸõ.
+    @brief M-text 中で文字を探す.
 
-    ؿ mtext_character ()  M-text $MT ʸ $C õ⤷ 
-    $FROM  $TO 꾮Сõϰ $FROM ء 
-    ($TO - 1) ޤǿʤࡣǤʤа ($FROM - 1) Ƭء
-    $TO ޤǿʤࡣ֤λ˸꤬ϡ$FROM  $TO 
-    ξ 0 ꤵ줿ΤȤߤʤ
+    関数 mtext_character () は M-text $MT 中で文字 $C を探す。もし 
+    $FROM が $TO より小さければ、探索は位置 $FROM から末尾方向へ、最大 
+    ($TO - 1) まで進む。そうでなければ位置 ($FROM - 1) から先頭方向へ、最大
+    $TO まで進む。位置の指定に誤りがある場合は、$FROM と $TO 
+    の両方に 0 が指定されたものとみなす。
 
     @return
-    ⤷ $C ĤСmtext_character () 
-    Ϥκǽνи֤֤Ĥʤäϳѿ #merror_code
-    ѹ -1 ֤顼Ф줿 -1 ֤ѿ
-    #merror_code ˥顼ɤꤹ롣  */
+    もし $C が見つかれば、mtext_character () 
+    はその最初の出現位置を返す。見つからなかった場合は外部変数 #merror_code
+    を変更せずに -1 を返す。エラーが検出された場合は -1 を返し、外部変数
+    #merror_code にエラーコードを設定する。  */
 
 /***
     @seealso
@@ -2822,14 +2824,14 @@ mtext_character (MText *mt, int from, int to, int c)
     returns -1.  */
 
 /***ja
-    @brief M-text ǻꤵ줿ʸǽ˸֤֤.
+    @brief M-text 中で指定された文字が最初に現れる位置を返す.
 
-    ؿ mtext_chr ()  M-text $MT ʸ $C õõ $MT 
-    Ƭ˿ʤࡣ
+    関数 mtext_chr () は M-text $MT 中で文字 $C を探す。探索は $MT 
+    の先頭から末尾方向に進む。
 
     @return
-    ⤷ $C ĤСmtext_chr () 
-    Ϥνи֤֤Ĥʤä -1 ֤
+    もし $C が見つかれば、mtext_chr () 
+    はその出現位置を返す。見つからなかった場合は -1 を返す。
 
     @latexonly \IPAlabel{mtext_chr} @endlatexonly  */
 
@@ -2860,14 +2862,14 @@ mtext_chr (MText *mt, int c)
     returns -1.  */
 
 /***ja
-    @brief M-text ǻꤵ줿ʸǸ˸֤֤.
+    @brief M-text 中で指定された文字が最後に現れる位置を返す.
 
-    ؿ mtext_rchr ()  M-text $MT ʸ $C õõ $MT 
-    κǸ夫Ƭؤȸ˿ʤࡣ
+    関数 mtext_rchr () は M-text $MT 中で文字 $C を探す。探索は $MT 
+    の最後から先頭方向へと後向きに進む。
 
     @return
-    ⤷ $C ĤСmtext_rchr () 
-    Ϥνи֤֤Ĥʤä -1 ֤
+    もし $C が見つかれば、mtext_rchr () 
+    はその出現位置を返す。見つからなかった場合は -1 を返す。
 
     @latexonly \IPAlabel{mtext_rchr} @endlatexonly  */
 
@@ -2899,13 +2901,13 @@ mtext_rchr (MText *mt, int c)
     character codes.  */
 
 /***ja
-    @brief Ĥ M-text ʸñ̤Ӥ.
+    @brief 二つの M-text を文字単位で比較する.
 
-    ؿ mtext_cmp () ϡ M-text $MT1  $MT2 ʸñ̤Ӥ롣
+    関数 mtext_cmp () は、 M-text $MT1 と $MT2 を文字単位で比較する。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 礭
-    1$MT1  $MT2 꾮 -1 ֤Ӥʸɤ˴Ť
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 より大きければ
+    1、$MT1 が $MT2 より小さければ -1 を返す。比較は文字コードに基づく。
 
     @latexonly \IPAlabel{mtext_cmp} @endlatexonly  */
 
@@ -2934,14 +2936,14 @@ mtext_cmp (MText *mt1, MText *mt2)
     equal to, or less than $MT2, respectively.  */
 
 /***ja
-    @brief Ĥ M-text Ƭʬʸñ̤Ӥ.
+    @brief 二つの M-text の先頭部分を文字単位で比較する.
 
-    ؿ mtext_ncmp () ϡؿ mtext_cmp () Ʊͤ M-text 
-    ƱΤӤƬ $N ʸޤǤ˴ؤƹԤʤ
+    関数 mtext_ncmp () は、関数 mtext_cmp () 同様の M-text 
+    同士の比較を先頭から最大 $N 文字までに関して行なう。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 礭 
-    1$MT1  $MT2 꾮 -1 ֤
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 より大きければ 
+    1、$MT1 が $MT2 より小さければ -1 を返す。
 
     @latexonly \IPAlabel{mtext_ncmp} @endlatexonly  */
 
@@ -2978,18 +2980,18 @@ mtext_ncmp (MText *mt1, MText *mt2, int n)
     character codes.  */
 
 /***ja
-    @brief Ĥ M-text λꤷΰƱΤӤ.
+    @brief 二つの M-text の指定した領域同士を比較する.
 
-    ؿ mtext_compare () Ĥ M-text $MT1  $MT2 
-    ʸñ̤Ӥ롣Ӥоݤ $MT1 Τ $FROM1  $TO1 ޤǤȡ$MT2 
-    Τ $FROM2  $TO2 ޤǤǤ롣$FROM1  $FROM2 ϴޤޤ졢$TO1 
-     $TO2 ϴޤޤʤ$FROM1  $TO1 ʤ뤤 $FROM2  $TO2 
-    ˤĹ M-text ̣롣ϰϻ˸꤬ϡ
-    $FROM1  $TO1 ʤ뤤 $FROM2  $TO2  ξ 0 ꤵ줿ΤȤߤʤ
+    関数 mtext_compare () は二つの M-text $MT1 と $MT2 
+    を文字単位で比較する。比較の対象は $MT1 のうち $FROM1 から $TO1 までと、$MT2 
+    のうち $FROM2 から $TO2 までである。$FROM1 と $FROM2 は含まれ、$TO1 
+    と $TO2 は含まれない。$FROM1 と $TO1 （あるいは $FROM2 と $TO2 
+    ）が等しい場合は長さゼロの M-text を意味する。範囲指定に誤りがある場合は、
+    $FROM1 と $TO1 （あるいは $FROM2 と $TO2 ） 両方に 0 が指定されたものとみなす。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 礭
-    1 $MT1  $MT2 꾮 -1 ֤Ӥʸɤ˴Ť  */
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 より大きければ
+    1 、$MT1 が $MT2 より小さければ -1 を返す。比較は文字コードに基づく。  */
 
 /***
     @seealso
@@ -3018,10 +3020,10 @@ mtext_compare (MText *mt1, int from1, int to1, MText *mt2, int from2, int to2)
     M-text $MT2.  */
 
 /***ja
-    @brief 뽸ʸ M-text õ.
+    @brief ある集合の文字を M-text の中で探す.
 
-    ؿ mtext_spn () ϡM-text $MT1 Ƭ M-text $MT2 
-    ˴ޤޤʸǤǤƤʬĹ֤
+    関数 mtext_spn () は、M-text $MT1 の先頭から M-text $MT2 
+    に含まれる文字だけでできている部分の長さを返す。
 
     @latexonly \IPAlabel{mtext_spn} @endlatexonly  */
 
@@ -3044,10 +3046,10 @@ mtext_spn (MText *mt, MText *accept)
     M-text $MT1 that consists entirely of characters not in M-text $MT2.  */
 
 /***ja
-    @brief 뽸°ʤʸ M-text õ.
+    @brief ある集合に属さない文字を M-text の中で探す.
 
-    ؿ mtext_cspn () ϡM-text $MT1 Ƭʬ M-text $MT2
-    ˴ޤޤʤʸǤǤƤʬĹ֤
+    関数 mtext_cspn () は、M-text $MT1 の先頭部分で M-text $MT2
+    に含まれない文字だけでできている部分の長さを返す。
 
     @latexonly \IPAlabel{mtext_cspn} @endlatexonly  */
 
@@ -3074,14 +3076,14 @@ mtext_cspn (MText *mt, MText *reject)
     If no such character is found, it returns -1. */
 
 /***ja
-    @brief 뽸°ʸ M-text 椫õ.
+    @brief ある集合に属す文字を M-text の中から探す.
 
-    ؿ mtext_pbrk () ϡM-text $MT1  M-text $MT2 
-    ʸΤɤ줫ǽ˸֤Ĵ٤롣
+    関数 mtext_pbrk () は、M-text $MT1 中で M-text $MT2 
+    の文字のどれかが最初に現れる位置を調べる。
 
     @return 
-    ĤäʸΡ$MT1 
-    ˤи֤֤⤷Τ褦ʸʤ -1 ֤
+    見つかった文字の、$MT1 
+    内における出現位置を返す。もしそのような文字がなければ -1 を返す。
 
     @latexonly \IPAlabel{mtext_pbrk} @endlatexonly  */
 
@@ -3113,19 +3115,19 @@ mtext_pbrk (MText *mt, MText *accept)
     to the external variable #merror_code. */
 
 /***ja
-    @brief M-text Υȡõ.
+    @brief M-text 中のトークンを探す.
 
-    ؿ mtext_tok () ϡM-text $MT ǰ $POS 
-    ʹߺǽ˸ȡõǥȡȤ M-text $DELIM
-    ˸ʤʸʤʬʸǤ롣$POS η @c int ǤϤʤ @c
-    int ؤΥݥ󥿤Ǥ뤳Ȥա
+    関数 mtext_tok () は、M-text $MT の中で位置 $POS 
+    以降最初に現れるトークンを探す。ここでトークンとは M-text $DELIM
+    の中に現われない文字だけからなる部分文字列である。$POS の型が @c int ではなくて @c
+    int へのポインタであることに注意。
 
     @return
-    ⤷ȡ󤬸Ĥ mtext_tok ()ϤΥȡʬ 
-    $MT 򥳥ԡΥԡؤΥݥ󥿤֤ξ硢$POS 
-    ϸĤäȡνü˥åȤ롣ȡ󤬸Ĥʤäϳѿ
-    #merror_code Ѥ @c NULL ֤顼Ф줿 
-    @c NULL ֤ѿ #merror_code ˥顼ɤꤹ롣
+    もしトークンが見つかれば mtext_tok ()はそのトークンに相当する部分の 
+    $MT をコピーし、そのコピーへのポインタを返す。この場合、$POS 
+    は見つかったトークンの終端にセットされる。トークンが見つからなかった場合は外部変数
+    #merror_code を変えずに @c NULL を返す。エラーが検出された場合は 
+    @c NULL を返し、変部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_tok} @endlatexonly  */
 
@@ -3170,14 +3172,14 @@ mtext_tok (MText *mt, MText *delim, int *pos)
     returns 0.  */
 
 /***ja
-    @brief M-text ̤ M-text õ.
+    @brief M-text 中で別の M-text を探す.
 
-    ؿ mtext_text () ϡM-text $MT1 ǰ $POS ʹߤ˸ 
-    M-text $MT2 κǽΰ֤Ĵ٤롣ƥȥץѥƥΰ㤤̵뤵롣
+    関数 mtext_text () は、M-text $MT1 中で位置 $POS 以降に現われる 
+    M-text $MT2 の最初の位置を調べる。テキストプロパティの違いは無視される。
 
     @return
-    $MT1  $MT2 ĤСmtext_text() 
-    Ϥκǽνи֤֤Ĥʤ -1 ֤⤷ $MT2 ʤ 0 ֤
+    $MT1 中に $MT2 が見つかれば、mtext_text() 
+    はその最初の出現位置を返す。見つからない場合は -1 を返す。もし $MT2 が空ならば 0 を返す。
 
     @latexonly \IPAlabel{mtext_text} @endlatexonly  */
 
@@ -3229,17 +3231,17 @@ mtext_text (MText *mt1, int pos, MText *mt2)
     returns 0.  */
 
 /***ja
-    @brief M-text ΰ̤ M-text õ.
+    @brief M-text 中の特定の領域で別の M-text を探す.
 
-    ؿ mtext_search () ϡM-text $MT1  $FROM  $TO 
-    ޤǤδ֤ΰM-text $MT2 
-    ǽ˸֤Ĵ٤롣ƥȥץѥƥΰ㤤̵뤵롣⤷
-    $FROM  $TO 꾮õϰ $FROM ءǤʤ
-    $TO Ƭؿʤࡣ
+    関数 mtext_search () は、M-text $MT1 中の $FROM から $TO 
+    までの間の領域でM-text $MT2 
+    が最初に現われる位置を調べる。テキストプロパティの違いは無視される。もし
+    $FROM が $TO より小さければ探索は位置 $FROM から末尾方向へ、そうでなければ
+    $TO から先頭方向へ進む。
 
     @return
-    $MT1  $MT2 ĤСmtext_search() 
-    Ϥκǽνи֤֤Ĥʤ -1 ֤⤷ $MT2 ʤ 0 ֤
+    $MT1 中に $MT2 が見つかれば、mtext_search() 
+    はその最初の出現位置を返す。見つからない場合は -1 を返す。もし $MT2 が空ならば 0 を返す。
     */
 
 int
@@ -3300,14 +3302,14 @@ mtext_search (MText *mt1, int from, int to, MText *mt2)
     equal to, or less than $MT2, respectively.  */
 
 /***ja
-    @brief Ĥ M-text ʸʸζ̵̤뤷Ӥ.
+    @brief 二つの M-text を大文字／小文字の区別を無視して比較する.
 
-    ؿ mtext_casecmp () ϡؿ mtext_cmp () Ʊͤ M-text 
-    ƱΤӤʸʸζ̵̤뤷ƹԤʤ
+    関数 mtext_casecmp () は、関数 mtext_cmp () 同様の M-text 
+    同士の比較を、大文字／小文字の区別を無視して行なう。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 
-    礭 1$MT1  $MT2 꾮 -1 ֤
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 
+    より大きければ 1、$MT1 が $MT2 より小さければ -1 を返す。
 
     @latexonly \IPAlabel{mtext_casecmp} @endlatexonly  */
 
@@ -3335,14 +3337,14 @@ mtext_casecmp (MText *mt1, MText *mt2)
     equal to, or less than $MT2, respectively.  */
 
 /***ja
-    @brief Ĥ M-text Ƭʬʸʸζ̵̤뤷Ӥ.
+    @brief 二つの M-text の先頭部分を大文字／小文字の区別を無視して比較する.
 
-    ؿ mtext_ncasecmp () ϡؿ mtext_casecmp () Ʊͤ M-text 
-    ƱΤӤƬ $N ʸޤǤ˴ؤƹԤʤ
+    関数 mtext_ncasecmp () は、関数 mtext_casecmp () 同様の M-text 
+    同士の比較を先頭から最大 $N 文字までに関して行なう。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 
-    礭 1$MT1  $MT2 꾮 -1 ֤
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 
+    より大きければ 1、$MT1 が $MT2 より小さければ -1 を返す。
 
     @latexonly \IPAlabel{mtext_ncasecmp} @endlatexonly  */
 
@@ -3380,19 +3382,19 @@ mtext_ncasecmp (MText *mt1, MText *mt2, int n)
     character codes.  */
 
 /***ja 
-    @brief Ĥ M-text λꤷΰʸʸζ̵̤뤷Ӥ.
+    @brief 二つの M-text の指定した領域を、大文字／小文字の区別を無視して比較する.
 
-    ؿ mtext_compare () Ĥ M-text $MT1  $MT2 
-    ʸʸζ̵̤뤷ʸñ̤Ӥ롣Ӥоݤ $MT1 
-     $FROM1  $TO1 ޤǡ$MT2  $FROM2  $TO2 ޤǤǤ롣
-    $FROM1  $FROM2 ϴޤޤ졢$TO1  $TO2 ϴޤޤʤ$FROM1  $TO1
-    ʤ뤤 $FROM2  $TO2 ˤĹ M-text 
-    ̣롣ϰϻ˸꤬ϡ$FROM1  $TO1 ʤ뤤 
-    $FROM2  $TO2 ξ 0 ꤵ줿Τȸʤ
+    関数 mtext_compare () は二つの M-text $MT1 と $MT2 
+    を、大文字／小文字の区別を無視して文字単位で比較する。比較の対象は $MT1 
+    の $FROM1 から $TO1 まで、$MT2 の $FROM2 から $TO2 までである。
+    $FROM1 と $FROM2 は含まれ、$TO1 と $TO2 は含まれない。$FROM1 と $TO1
+    （あるいは $FROM2 と $TO2 ）が等しい場合は長さゼロの M-text 
+    を意味する。範囲指定に誤りがある場合は、$FROM1 と $TO1 （あるいは 
+    $FROM2 と $TO2 ）両方に 0 が指定されたものと見なす。
 
     @return
-    δؿϡ$MT1  $MT2  0$MT1  $MT2 礭
-    1$MT1  $MT2 꾮 -1֤Ӥʸɤ˴Ť
+    この関数は、$MT1 と $MT2 が等しければ 0、$MT1 が $MT2 より大きければ
+    1、$MT1 が $MT2 より小さければ -1を返す。比較は文字コードに基づく。
 
   @latexonly \IPAlabel{mtext_case_compare} @endlatexonly
 */
@@ -3432,16 +3434,16 @@ mtext_case_compare (MText *mt1, int from1, int to1,
 */
 
 /***ja
-    @brief M-text ʸˤ.
+    @brief M-text を小文字にする.
 
-    ؿ mtext_lowercase ()  M-text $MT γʸ˲Ū˾ʸ
-    롣Ѵ˺ݤܤʸαƶ뤳Ȥ롣$MT ˥
-    ȥץѥƥ Mlanguage դƤϡѴ˱ƶ
-    Ϳ롣$MT ĹѤ뤳Ȥ롣ʸѴǤʤäʸ
-    ϤΤޤ޻Ĥ롣ƥȥץѥƥϤ٤ƷѾ롣
+    関数 mtext_lowercase () は M-text $MT 中の各文字を破壊的に小文字に変
+    換する。変換に際して隣接する文字の影響を受けることがある。$MT にテ
+    キストプロパティ Mlanguage が付いている場合は、それも変換に影響を
+    与えうる。$MT の長さは変わることがある。小文字に変換できなかった文
+    字はそのまま残る。テキストプロパティはすべて継承される。
 
     @return
-    δؿϹ $MT Ĺ֤
+    この関数は更新後の $MT の長さを返す。
 */
 
 /***
@@ -3474,16 +3476,16 @@ mtext_lowercase (MText *mt)
 */
 
 /***ja
-    @brief M-text 򥿥ȥ륱ˤ.
+    @brief M-text をタイトルケースにする.
 
-    ؿ mtext_titlecase ()  M-text $MT  cased ץѥƥ
-    ǽʸ򥿥ȥ륱ˡƤʹߤʸʸ˲Ū
-    Ѵ롣$MT ĹѤ뤳Ȥ롣ȥ륱ˤѴ
-    ʤäϤΤޤޤѤʤƥȥץѥƥϤ٤Ʒ
-    롣
+    関数 mtext_titlecase () は M-text $MT 中で cased プロパティを持つ
+    最初の文字をタイトルケースに、そしてそれ以降の文字を小文字に破壊的
+    に変換する。$MT の長さは変わることがある。タイトルケースにに変換で
+    きなかった場合はそのままで変わらない。テキストプロパティはすべて継
+    承される。
 
     @return
-    δؿϹ $MT Ĺ֤
+    この関数は更新後の $MT の長さを返す。
 */
 
 /***
@@ -3545,16 +3547,16 @@ mtext_titlecase (MText *mt)
 */
 
 /***ja
-    @brief M-text ʸˤ.
+    @brief M-text を大文字にする.
 
-    ؿ mtext_uppercase ()  M-text $MT γʸ˲Ūʸ
-    롣Ѵ˺ݤܤʸαƶ뤳Ȥ롣$MT ˥
-    ȥץѥƥ Mlanguage դƤϡѴ˱ƶ
-    Ϳ롣$MT ĹѤ뤳Ȥ롣ʸѴǤʤäʸ
-    ϤΤޤ޻Ĥ롣ƥȥץѥƥϤ٤ƷѾ롣
+    関数 mtext_uppercase () は M-text $MT 中の各文字を破壊的に大文字に変
+    換する。変換に際して隣接する文字の影響を受けることがある。$MT にテ
+    キストプロパティ Mlanguage が付いている場合は、それも変換に影響を
+    与えうる。$MT の長さは変わることがある。大文字に変換できなかった文
+    字はそのまま残る。テキストプロパティはすべて継承される。
 
     @return
-    δؿϹ $MT Ĺ֤
+    この関数は更新後の $MT の長さを返す。
 */
 
 /***
@@ -3582,23 +3584,25 @@ mtext_uppercase (MText *mt)
     @brief Dump an M-text.
 
     The mdebug_dump_mtext () function prints the M-text $MT in a human
-    readable way to the stderr.  $INDENT specifies how many columns to
-    indent the lines but the first one.  If $FULLP is zero, this
+    readable way to the stderr or to what specified by the environment
+    variable MDEBUG_OUTPUT_FILE.  $INDENT specifies how many columns
+    to indent the lines but the first one.  If $FULLP is zero, this
     function prints only a character code sequence.  Otherwise, it
     prints the internal byte sequence and text properties as well.
 
     @return
     This function returns $MT.  */
 /***ja
-    @brief M-text פ.
+    @brief M-text をダンプする.
 
-    ؿ mdebug_dump_mtext ()  M-text $MT  stderr 
-    ˿ʹ֤˲ɤʷǰ롣 $INDENT ϣܰʹߤΥǥȤꤹ롣
-    $FULLP  0 ʤСʸ롣
-    ǤʤСХȥƥȥץѥƥ롣
+    関数 mdebug_dump_mtext () は M-text $MT を標準エラー出力もしくは環
+    境変数 MDEBUG_DUMP_FONT で指定されたファイルに人間に可読な形で印刷
+    する。 $INDENT は２行目以降のインデントを指定する。$FULLP が 0 なら
+    ば、文字コード列だけを印刷する。そうでなければ、内部バイト列とテキ
+    ストプロパティも印刷する。
 
     @return
-    δؿ $MT ֤  */
+    この関数は $MT を返す。  */
 
 MText *
 mdebug_dump_mtext (MText *mt, int indent, int fullp)
@@ -3607,23 +3611,23 @@ mdebug_dump_mtext (MText *mt, int indent, int fullp)
 
   if (! fullp)
     {
-      fprintf (stderr, "\"");
+      fprintf (mdebug__output, "\"");
       for (i = 0; i < mt->nchars; i++)
 	{
 	  int c = mtext_ref_char (mt, i);
 
 	  if (c == '"' || c == '\\')
-	    fprintf (stderr, "\\%c", c);
+	    fprintf (mdebug__output, "\\%c", c);
 	  else if ((c >= ' ' && c < 127) || c == '\n')
-	    fprintf (stderr, "%c", c);
+	    fprintf (mdebug__output, "%c", c);
 	  else
-	    fprintf (stderr, "\\x%02X", c);
+	    fprintf (mdebug__output, "\\x%02X", c);
 	}
-      fprintf (stderr, "\"");
+      fprintf (mdebug__output, "\"");
       return mt;
     }
 
-  fprintf (stderr,
+  fprintf (mdebug__output,
 	   "(mtext (size %d %d %d) (cache %d %d)",
 	   mt->nchars, mt->nbytes, mt->allocated,
 	   mt->cache_char_pos, mt->cache_byte_pos);
@@ -3636,11 +3640,11 @@ mdebug_dump_mtext (MText *mt, int indent, int fullp)
       memset (prefix, 32, indent);
       prefix[indent] = 0;
 
-      fprintf (stderr, "\n%s (bytes \"", prefix);
+      fprintf (mdebug__output, "\n%s (bytes \"", prefix);
       for (i = 0; i < mt->nbytes; i++)
-	fprintf (stderr, "\\x%02x", mt->data[i]);
-      fprintf (stderr, "\")\n");
-      fprintf (stderr, "%s (chars \"", prefix);
+	fprintf (mdebug__output, "\\x%02x", mt->data[i]);
+      fprintf (mdebug__output, "\")\n");
+      fprintf (mdebug__output, "%s (chars \"", prefix);
       p = mt->data;
       for (i = 0; i < mt->nchars; i++)
 	{
@@ -3648,21 +3652,21 @@ mdebug_dump_mtext (MText *mt, int indent, int fullp)
 	  int c = STRING_CHAR_AND_BYTES (p, len);
 
 	  if (c == '"' || c == '\\')
-	    fprintf (stderr, "\\%c", c);
+	    fprintf (mdebug__output, "\\%c", c);
 	  else if (c >= ' ' && c < 127)
-	    fputc (c, stderr);
+	    fputc (c, mdebug__output);
 	  else
-	    fprintf (stderr, "\\x%X", c);
+	    fprintf (mdebug__output, "\\x%X", c);
 	  p += len;
 	}
-      fprintf (stderr, "\")");
+      fprintf (mdebug__output, "\")");
       if (mt->plist)
 	{
-	  fprintf (stderr, "\n%s ", prefix);
+	  fprintf (mdebug__output, "\n%s ", prefix);
 	  dump_textplist (mt->plist, indent + 1);
 	}
     }
-  fprintf (stderr, ")");
+  fprintf (mdebug__output, ")");
   return mt;
 }
 
@@ -3670,6 +3674,6 @@ mdebug_dump_mtext (MText *mt, int indent, int fullp)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
